@@ -1,3 +1,4 @@
+#[doc = "*Required features: `\"Devices_Custom\"`, `\"implement\"`*"]
 pub trait IIOControlCode_Impl: Sized {
     fn AccessMode(&self) -> ::windows::core::Result<IOControlAccessMode>;
     fn BufferingMethod(&self) -> ::windows::core::Result<IOControlBufferingMethod>;
@@ -71,7 +72,7 @@ impl IIOControlCode_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IIOControlCode, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IIOControlCode, OFFSET>(),
             AccessMode: AccessMode::<Identity, Impl, OFFSET>,
             BufferingMethod: BufferingMethod::<Identity, Impl, OFFSET>,
             Function: Function::<Identity, Impl, OFFSET>,
@@ -80,6 +81,6 @@ impl IIOControlCode_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IIOControlCode as ::windows::core::Interface>::IID
+        iid == &<IIOControlCode as ::windows::core::ComInterface>::IID
     }
 }
