@@ -1,3 +1,4 @@
+#[doc = "*Required features: `\"Devices_Sensors\"`, `\"implement\"`*"]
 pub trait ISensorDataThreshold_Impl: Sized {}
 impl ::windows::core::RuntimeName for ISensorDataThreshold {
     const NAME: &'static str = "Windows.Devices.Sensors.ISensorDataThreshold";
@@ -7,6 +8,6 @@ impl ISensorDataThreshold_Vtbl {
         Self { base__: ::windows::core::IInspectable_Vtbl::new::<Identity, ISensorDataThreshold, OFFSET>() }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<ISensorDataThreshold as ::windows::core::Interface>::IID
+        iid == &<ISensorDataThreshold as ::windows::core::ComInterface>::IID
     }
 }
