@@ -1,17 +1,22 @@
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct ILanguageFont(::windows::core::IUnknown);
-unsafe impl ::windows::core::Vtable for ILanguageFont {
+unsafe impl ::windows::core::Interface for ILanguageFont {
     type Vtable = ILanguageFont_Vtbl;
 }
-unsafe impl ::windows::core::Interface for ILanguageFont {
+impl ::core::clone::Clone for ILanguageFont {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+unsafe impl ::windows::core::ComInterface for ILanguageFont {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xb12e5c3a_b76d_459b_beeb_901151cd77d1);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ILanguageFont_Vtbl {
     pub base__: ::windows::core::IInspectable_Vtbl,
-    pub FontFamily: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
+    pub FontFamily: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::std::mem::MaybeUninit<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
     #[cfg(feature = "UI_Text")]
     pub FontWeight: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut super::super::UI::Text::FontWeight) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "UI_Text"))]
@@ -29,10 +34,15 @@ pub struct ILanguageFont_Vtbl {
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct ILanguageFontGroup(::windows::core::IUnknown);
-unsafe impl ::windows::core::Vtable for ILanguageFontGroup {
+unsafe impl ::windows::core::Interface for ILanguageFontGroup {
     type Vtable = ILanguageFontGroup_Vtbl;
 }
-unsafe impl ::windows::core::Interface for ILanguageFontGroup {
+impl ::core::clone::Clone for ILanguageFontGroup {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+unsafe impl ::windows::core::ComInterface for ILanguageFontGroup {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xf33a7fc3_3a5c_4aea_b9ff_b39fb242f7f6);
 }
 #[repr(C)]
@@ -54,17 +64,22 @@ pub struct ILanguageFontGroup_Vtbl {
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct ILanguageFontGroupFactory(::windows::core::IUnknown);
-unsafe impl ::windows::core::Vtable for ILanguageFontGroupFactory {
+unsafe impl ::windows::core::Interface for ILanguageFontGroupFactory {
     type Vtable = ILanguageFontGroupFactory_Vtbl;
 }
-unsafe impl ::windows::core::Interface for ILanguageFontGroupFactory {
+impl ::core::clone::Clone for ILanguageFontGroupFactory {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+unsafe impl ::windows::core::ComInterface for ILanguageFontGroupFactory {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xfcaeac67_4e77_49c7_b856_dde934fc735b);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ILanguageFontGroupFactory_Vtbl {
     pub base__: ::windows::core::IInspectable_Vtbl,
-    pub CreateLanguageFontGroup: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, languagetag: ::core::mem::ManuallyDrop<::windows::core::HSTRING>, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
+    pub CreateLanguageFontGroup: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, languagetag: ::std::mem::MaybeUninit<::windows::core::HSTRING>, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
 #[doc = "*Required features: `\"Globalization_Fonts\"`*"]
 #[repr(transparent)]
@@ -73,8 +88,8 @@ impl LanguageFont {
     pub fn FontFamily(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).FontFamily)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            let mut result__ = ::windows::core::zeroed::<::windows::core::HSTRING>();
+            (::windows::core::Interface::vtable(this).FontFamily)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     #[doc = "*Required features: `\"UI_Text\"`*"]
@@ -82,8 +97,8 @@ impl LanguageFont {
     pub fn FontWeight(&self) -> ::windows::core::Result<super::super::UI::Text::FontWeight> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).FontWeight)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontWeight>(result__)
+            let mut result__ = ::windows::core::zeroed::<super::super::UI::Text::FontWeight>();
+            (::windows::core::Interface::vtable(this).FontWeight)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     #[doc = "*Required features: `\"UI_Text\"`*"]
@@ -91,8 +106,8 @@ impl LanguageFont {
     pub fn FontStretch(&self) -> ::windows::core::Result<super::super::UI::Text::FontStretch> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).FontStretch)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontStretch>(result__)
+            let mut result__ = ::windows::core::zeroed::<super::super::UI::Text::FontStretch>();
+            (::windows::core::Interface::vtable(this).FontStretch)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     #[doc = "*Required features: `\"UI_Text\"`*"]
@@ -100,23 +115,18 @@ impl LanguageFont {
     pub fn FontStyle(&self) -> ::windows::core::Result<super::super::UI::Text::FontStyle> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).FontStyle)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontStyle>(result__)
+            let mut result__ = ::windows::core::zeroed::<super::super::UI::Text::FontStyle>();
+            (::windows::core::Interface::vtable(this).FontStyle)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn ScaleFactor(&self) -> ::windows::core::Result<f64> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).ScaleFactor)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<f64>(result__)
+            let mut result__ = ::windows::core::zeroed::<f64>();
+            (::windows::core::Interface::vtable(this).ScaleFactor)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
 }
-impl ::core::clone::Clone for LanguageFont {
-    fn clone(&self) -> Self {
-        Self(self.0.clone())
-    }
-}
 impl ::core::cmp::PartialEq for LanguageFont {
     fn eq(&self, other: &Self) -> bool {
         self.0 == other.0
@@ -128,23 +138,24 @@ impl ::core::fmt::Debug for LanguageFont {
         f.debug_tuple("LanguageFont").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::RuntimeType for LanguageFont {
-    const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Globalization.Fonts.LanguageFont;{b12e5c3a-b76d-459b-beeb-901151cd77d1})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+impl ::windows::core::RuntimeType for LanguageFont {
+    const SIGNATURE: ::windows::imp::ConstBuffer = ::windows::imp::ConstBuffer::from_slice(b"rc(Windows.Globalization.Fonts.LanguageFont;{b12e5c3a-b76d-459b-beeb-901151cd77d1})");
+}
+impl ::core::clone::Clone for LanguageFont {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
     }
 }
-unsafe impl ::windows::core::Vtable for LanguageFont {
+unsafe impl ::windows::core::Interface for LanguageFont {
     type Vtable = ILanguageFont_Vtbl;
 }
-unsafe impl ::windows::core::Interface for LanguageFont {
-    const IID: ::windows::core::GUID = <ILanguageFont as ::windows::core::Interface>::IID;
+unsafe impl ::windows::core::ComInterface for LanguageFont {
+    const IID: ::windows::core::GUID = <ILanguageFont as ::windows::core::ComInterface>::IID;
 }
 impl ::windows::core::RuntimeName for LanguageFont {
     const NAME: &'static str = "Windows.Globalization.Fonts.LanguageFont";
 }
-::windows::core::interface_hierarchy!(LanguageFont, ::windows::core::IUnknown, ::windows::core::IInspectable);
+::windows::imp::interface_hierarchy!(LanguageFont, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for LanguageFont {}
 unsafe impl ::core::marker::Sync for LanguageFont {}
 #[doc = "*Required features: `\"Globalization_Fonts\"`*"]
@@ -154,97 +165,92 @@ impl LanguageFontGroup {
     pub fn UITextFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).UITextFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).UITextFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn UIHeadingFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).UIHeadingFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).UIHeadingFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn UITitleFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).UITitleFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).UITitleFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn UICaptionFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).UICaptionFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).UICaptionFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn UINotificationHeadingFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).UINotificationHeadingFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).UINotificationHeadingFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn TraditionalDocumentFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).TraditionalDocumentFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).TraditionalDocumentFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn ModernDocumentFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).ModernDocumentFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).ModernDocumentFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn DocumentHeadingFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).DocumentHeadingFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).DocumentHeadingFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn FixedWidthTextFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).FixedWidthTextFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).FixedWidthTextFont)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn DocumentAlternate1Font(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).DocumentAlternate1Font)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).DocumentAlternate1Font)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn DocumentAlternate2Font(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).DocumentAlternate2Font)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFont>();
+            (::windows::core::Interface::vtable(this).DocumentAlternate2Font)(::windows::core::Interface::as_raw(this), &mut result__).from_abi(result__)
         }
     }
     pub fn CreateLanguageFontGroup(languagetag: &::windows::core::HSTRING) -> ::windows::core::Result<LanguageFontGroup> {
         Self::ILanguageFontGroupFactory(|this| unsafe {
-            let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Vtable::vtable(this).CreateLanguageFontGroup)(::windows::core::Vtable::as_raw(this), ::core::mem::transmute_copy(languagetag), result__.as_mut_ptr()).from_abi::<LanguageFontGroup>(result__)
+            let mut result__ = ::windows::core::zeroed::<LanguageFontGroup>();
+            (::windows::core::Interface::vtable(this).CreateLanguageFontGroup)(::windows::core::Interface::as_raw(this), ::core::mem::transmute_copy(languagetag), &mut result__).from_abi(result__)
         })
     }
     #[doc(hidden)]
     pub fn ILanguageFontGroupFactory<R, F: FnOnce(&ILanguageFontGroupFactory) -> ::windows::core::Result<R>>(callback: F) -> ::windows::core::Result<R> {
-        static SHARED: ::windows::core::FactoryCache<LanguageFontGroup, ILanguageFontGroupFactory> = ::windows::core::FactoryCache::new();
+        static SHARED: ::windows::imp::FactoryCache<LanguageFontGroup, ILanguageFontGroupFactory> = ::windows::imp::FactoryCache::new();
         SHARED.call(callback)
     }
 }
-impl ::core::clone::Clone for LanguageFontGroup {
-    fn clone(&self) -> Self {
-        Self(self.0.clone())
-    }
-}
 impl ::core::cmp::PartialEq for LanguageFontGroup {
     fn eq(&self, other: &Self) -> bool {
         self.0 == other.0
@@ -256,23 +262,24 @@ impl ::core::fmt::Debug for LanguageFontGroup {
         f.debug_tuple("LanguageFontGroup").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::RuntimeType for LanguageFontGroup {
-    const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Globalization.Fonts.LanguageFontGroup;{f33a7fc3-3a5c-4aea-b9ff-b39fb242f7f6})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+impl ::windows::core::RuntimeType for LanguageFontGroup {
+    const SIGNATURE: ::windows::imp::ConstBuffer = ::windows::imp::ConstBuffer::from_slice(b"rc(Windows.Globalization.Fonts.LanguageFontGroup;{f33a7fc3-3a5c-4aea-b9ff-b39fb242f7f6})");
+}
+impl ::core::clone::Clone for LanguageFontGroup {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
     }
 }
-unsafe impl ::windows::core::Vtable for LanguageFontGroup {
+unsafe impl ::windows::core::Interface for LanguageFontGroup {
     type Vtable = ILanguageFontGroup_Vtbl;
 }
-unsafe impl ::windows::core::Interface for LanguageFontGroup {
-    const IID: ::windows::core::GUID = <ILanguageFontGroup as ::windows::core::Interface>::IID;
+unsafe impl ::windows::core::ComInterface for LanguageFontGroup {
+    const IID: ::windows::core::GUID = <ILanguageFontGroup as ::windows::core::ComInterface>::IID;
 }
 impl ::windows::core::RuntimeName for LanguageFontGroup {
     const NAME: &'static str = "Windows.Globalization.Fonts.LanguageFontGroup";
 }
-::windows::core::interface_hierarchy!(LanguageFontGroup, ::windows::core::IUnknown, ::windows::core::IInspectable);
+::windows::imp::interface_hierarchy!(LanguageFontGroup, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for LanguageFontGroup {}
 unsafe impl ::core::marker::Sync for LanguageFontGroup {}
 #[cfg(feature = "implement")]
