@@ -1,3 +1,4 @@
+#[doc = "*Required features: `\"Media_Effects\"`, `\"Foundation_Collections\"`, `\"implement\"`*"]
 #[cfg(feature = "Foundation_Collections")]
 pub trait IAudioEffectDefinition_Impl: Sized {
     fn ActivatableClassId(&self) -> ::windows::core::Result<::windows::core::HSTRING>;
@@ -10,7 +11,7 @@ impl ::windows::core::RuntimeName for IAudioEffectDefinition {
 #[cfg(feature = "Foundation_Collections")]
 impl IAudioEffectDefinition_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IAudioEffectDefinition_Impl, const OFFSET: isize>() -> IAudioEffectDefinition_Vtbl {
-        unsafe extern "system" fn ActivatableClassId<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IAudioEffectDefinition_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn ActivatableClassId<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IAudioEffectDefinition_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, result__: *mut ::std::mem::MaybeUninit<::windows::core::HSTRING>) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
             match this.ActivatableClassId() {
@@ -35,21 +36,22 @@ impl IAudioEffectDefinition_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IAudioEffectDefinition, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IAudioEffectDefinition, OFFSET>(),
             ActivatableClassId: ActivatableClassId::<Identity, Impl, OFFSET>,
             Properties: Properties::<Identity, Impl, OFFSET>,
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IAudioEffectDefinition as ::windows::core::Interface>::IID
+        iid == &<IAudioEffectDefinition as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Media_Effects\"`, `\"Foundation_Collections\"`, `\"Media_MediaProperties\"`, `\"implement\"`*"]
 #[cfg(all(feature = "Foundation_Collections", feature = "Media_MediaProperties"))]
 pub trait IBasicAudioEffect_Impl: Sized + super::IMediaExtension_Impl {
     fn UseInputFrameForOutput(&self) -> ::windows::core::Result<bool>;
     fn SupportedEncodingProperties(&self) -> ::windows::core::Result<super::super::Foundation::Collections::IVectorView<super::MediaProperties::AudioEncodingProperties>>;
-    fn SetEncodingProperties(&self, encodingproperties: &::core::option::Option<super::MediaProperties::AudioEncodingProperties>) -> ::windows::core::Result<()>;
-    fn ProcessFrame(&self, context: &::core::option::Option<ProcessAudioFrameContext>) -> ::windows::core::Result<()>;
+    fn SetEncodingProperties(&self, encodingproperties: ::core::option::Option<&super::MediaProperties::AudioEncodingProperties>) -> ::windows::core::Result<()>;
+    fn ProcessFrame(&self, context: ::core::option::Option<&ProcessAudioFrameContext>) -> ::windows::core::Result<()>;
     fn Close(&self, reason: MediaEffectClosedReason) -> ::windows::core::Result<()>;
     fn DiscardQueuedFrames(&self) -> ::windows::core::Result<()>;
 }
@@ -87,12 +89,12 @@ impl IBasicAudioEffect_Vtbl {
         unsafe extern "system" fn SetEncodingProperties<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IBasicAudioEffect_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, encodingproperties: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            this.SetEncodingProperties(::core::mem::transmute(&encodingproperties)).into()
+            this.SetEncodingProperties(::windows::core::from_raw_borrowed(&encodingproperties)).into()
         }
         unsafe extern "system" fn ProcessFrame<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IBasicAudioEffect_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, context: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            this.ProcessFrame(::core::mem::transmute(&context)).into()
+            this.ProcessFrame(::windows::core::from_raw_borrowed(&context)).into()
         }
         unsafe extern "system" fn Close<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IBasicAudioEffect_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, reason: MediaEffectClosedReason) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
@@ -105,7 +107,7 @@ impl IBasicAudioEffect_Vtbl {
             this.DiscardQueuedFrames().into()
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IBasicAudioEffect, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IBasicAudioEffect, OFFSET>(),
             UseInputFrameForOutput: UseInputFrameForOutput::<Identity, Impl, OFFSET>,
             SupportedEncodingProperties: SupportedEncodingProperties::<Identity, Impl, OFFSET>,
             SetEncodingProperties: SetEncodingProperties::<Identity, Impl, OFFSET>,
@@ -115,17 +117,18 @@ impl IBasicAudioEffect_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IBasicAudioEffect as ::windows::core::Interface>::IID
+        iid == &<IBasicAudioEffect as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Media_Effects\"`, `\"Foundation_Collections\"`, `\"Graphics_DirectX_Direct3D11\"`, `\"Media_MediaProperties\"`, `\"implement\"`*"]
 #[cfg(all(feature = "Foundation_Collections", feature = "Graphics_DirectX_Direct3D11", feature = "Media_MediaProperties"))]
 pub trait IBasicVideoEffect_Impl: Sized + super::IMediaExtension_Impl {
     fn IsReadOnly(&self) -> ::windows::core::Result<bool>;
     fn SupportedMemoryTypes(&self) -> ::windows::core::Result<MediaMemoryTypes>;
     fn TimeIndependent(&self) -> ::windows::core::Result<bool>;
     fn SupportedEncodingProperties(&self) -> ::windows::core::Result<super::super::Foundation::Collections::IVectorView<super::MediaProperties::VideoEncodingProperties>>;
-    fn SetEncodingProperties(&self, encodingproperties: &::core::option::Option<super::MediaProperties::VideoEncodingProperties>, device: &::core::option::Option<super::super::Graphics::DirectX::Direct3D11::IDirect3DDevice>) -> ::windows::core::Result<()>;
-    fn ProcessFrame(&self, context: &::core::option::Option<ProcessVideoFrameContext>) -> ::windows::core::Result<()>;
+    fn SetEncodingProperties(&self, encodingproperties: ::core::option::Option<&super::MediaProperties::VideoEncodingProperties>, device: ::core::option::Option<&super::super::Graphics::DirectX::Direct3D11::IDirect3DDevice>) -> ::windows::core::Result<()>;
+    fn ProcessFrame(&self, context: ::core::option::Option<&ProcessVideoFrameContext>) -> ::windows::core::Result<()>;
     fn Close(&self, reason: MediaEffectClosedReason) -> ::windows::core::Result<()>;
     fn DiscardQueuedFrames(&self) -> ::windows::core::Result<()>;
 }
@@ -187,12 +190,12 @@ impl IBasicVideoEffect_Vtbl {
         unsafe extern "system" fn SetEncodingProperties<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IBasicVideoEffect_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, encodingproperties: *mut ::core::ffi::c_void, device: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            this.SetEncodingProperties(::core::mem::transmute(&encodingproperties), ::core::mem::transmute(&device)).into()
+            this.SetEncodingProperties(::windows::core::from_raw_borrowed(&encodingproperties), ::windows::core::from_raw_borrowed(&device)).into()
         }
         unsafe extern "system" fn ProcessFrame<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IBasicVideoEffect_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, context: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            this.ProcessFrame(::core::mem::transmute(&context)).into()
+            this.ProcessFrame(::windows::core::from_raw_borrowed(&context)).into()
         }
         unsafe extern "system" fn Close<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IBasicVideoEffect_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, reason: MediaEffectClosedReason) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
@@ -205,7 +208,7 @@ impl IBasicVideoEffect_Vtbl {
             this.DiscardQueuedFrames().into()
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IBasicVideoEffect, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IBasicVideoEffect, OFFSET>(),
             IsReadOnly: IsReadOnly::<Identity, Impl, OFFSET>,
             SupportedMemoryTypes: SupportedMemoryTypes::<Identity, Impl, OFFSET>,
             TimeIndependent: TimeIndependent::<Identity, Impl, OFFSET>,
@@ -217,14 +220,15 @@ impl IBasicVideoEffect_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IBasicVideoEffect as ::windows::core::Interface>::IID
+        iid == &<IBasicVideoEffect as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Media_Effects\"`, `\"Foundation_Collections\"`, `\"Graphics_DirectX_Direct3D11\"`, `\"Media_MediaProperties\"`, `\"implement\"`*"]
 #[cfg(all(feature = "Foundation_Collections", feature = "Graphics_DirectX_Direct3D11", feature = "Media_MediaProperties"))]
 pub trait IVideoCompositor_Impl: Sized + super::IMediaExtension_Impl {
     fn TimeIndependent(&self) -> ::windows::core::Result<bool>;
-    fn SetEncodingProperties(&self, backgroundproperties: &::core::option::Option<super::MediaProperties::VideoEncodingProperties>, device: &::core::option::Option<super::super::Graphics::DirectX::Direct3D11::IDirect3DDevice>) -> ::windows::core::Result<()>;
-    fn CompositeFrame(&self, context: &::core::option::Option<CompositeVideoFrameContext>) -> ::windows::core::Result<()>;
+    fn SetEncodingProperties(&self, backgroundproperties: ::core::option::Option<&super::MediaProperties::VideoEncodingProperties>, device: ::core::option::Option<&super::super::Graphics::DirectX::Direct3D11::IDirect3DDevice>) -> ::windows::core::Result<()>;
+    fn CompositeFrame(&self, context: ::core::option::Option<&CompositeVideoFrameContext>) -> ::windows::core::Result<()>;
     fn Close(&self, reason: MediaEffectClosedReason) -> ::windows::core::Result<()>;
     fn DiscardQueuedFrames(&self) -> ::windows::core::Result<()>;
 }
@@ -250,12 +254,12 @@ impl IVideoCompositor_Vtbl {
         unsafe extern "system" fn SetEncodingProperties<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoCompositor_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, backgroundproperties: *mut ::core::ffi::c_void, device: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            this.SetEncodingProperties(::core::mem::transmute(&backgroundproperties), ::core::mem::transmute(&device)).into()
+            this.SetEncodingProperties(::windows::core::from_raw_borrowed(&backgroundproperties), ::windows::core::from_raw_borrowed(&device)).into()
         }
         unsafe extern "system" fn CompositeFrame<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoCompositor_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, context: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            this.CompositeFrame(::core::mem::transmute(&context)).into()
+            this.CompositeFrame(::windows::core::from_raw_borrowed(&context)).into()
         }
         unsafe extern "system" fn Close<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoCompositor_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, reason: MediaEffectClosedReason) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
@@ -268,7 +272,7 @@ impl IVideoCompositor_Vtbl {
             this.DiscardQueuedFrames().into()
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IVideoCompositor, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IVideoCompositor, OFFSET>(),
             TimeIndependent: TimeIndependent::<Identity, Impl, OFFSET>,
             SetEncodingProperties: SetEncodingProperties::<Identity, Impl, OFFSET>,
             CompositeFrame: CompositeFrame::<Identity, Impl, OFFSET>,
@@ -277,9 +281,10 @@ impl IVideoCompositor_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IVideoCompositor as ::windows::core::Interface>::IID
+        iid == &<IVideoCompositor as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Media_Effects\"`, `\"Foundation_Collections\"`, `\"implement\"`*"]
 #[cfg(feature = "Foundation_Collections")]
 pub trait IVideoCompositorDefinition_Impl: Sized {
     fn ActivatableClassId(&self) -> ::windows::core::Result<::windows::core::HSTRING>;
@@ -292,7 +297,7 @@ impl ::windows::core::RuntimeName for IVideoCompositorDefinition {
 #[cfg(feature = "Foundation_Collections")]
 impl IVideoCompositorDefinition_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoCompositorDefinition_Impl, const OFFSET: isize>() -> IVideoCompositorDefinition_Vtbl {
-        unsafe extern "system" fn ActivatableClassId<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoCompositorDefinition_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn ActivatableClassId<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoCompositorDefinition_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, result__: *mut ::std::mem::MaybeUninit<::windows::core::HSTRING>) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
             match this.ActivatableClassId() {
@@ -317,15 +322,16 @@ impl IVideoCompositorDefinition_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IVideoCompositorDefinition, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IVideoCompositorDefinition, OFFSET>(),
             ActivatableClassId: ActivatableClassId::<Identity, Impl, OFFSET>,
             Properties: Properties::<Identity, Impl, OFFSET>,
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IVideoCompositorDefinition as ::windows::core::Interface>::IID
+        iid == &<IVideoCompositorDefinition as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Media_Effects\"`, `\"Foundation_Collections\"`, `\"implement\"`*"]
 #[cfg(feature = "Foundation_Collections")]
 pub trait IVideoEffectDefinition_Impl: Sized {
     fn ActivatableClassId(&self) -> ::windows::core::Result<::windows::core::HSTRING>;
@@ -338,7 +344,7 @@ impl ::windows::core::RuntimeName for IVideoEffectDefinition {
 #[cfg(feature = "Foundation_Collections")]
 impl IVideoEffectDefinition_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoEffectDefinition_Impl, const OFFSET: isize>() -> IVideoEffectDefinition_Vtbl {
-        unsafe extern "system" fn ActivatableClassId<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoEffectDefinition_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn ActivatableClassId<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IVideoEffectDefinition_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, result__: *mut ::std::mem::MaybeUninit<::windows::core::HSTRING>) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
             match this.ActivatableClassId() {
@@ -363,12 +369,12 @@ impl IVideoEffectDefinition_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IVideoEffectDefinition, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IVideoEffectDefinition, OFFSET>(),
             ActivatableClassId: ActivatableClassId::<Identity, Impl, OFFSET>,
             Properties: Properties::<Identity, Impl, OFFSET>,
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IVideoEffectDefinition as ::windows::core::Interface>::IID
+        iid == &<IVideoEffectDefinition as ::windows::core::ComInterface>::IID
     }
 }
