@@ -1,6 +1,6 @@
 #[doc = "*Required features: `\"Media_Render\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct AudioRenderCategory(pub i32);
 impl AudioRenderCategory {
     pub const Other: Self = Self(0i32);
@@ -27,20 +27,16 @@ impl ::core::default::Default for AudioRenderCategory {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for AudioRenderCategory {
-    type Abi = Self;
+impl ::windows::core::TypeKind for AudioRenderCategory {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for AudioRenderCategory {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_tuple("AudioRenderCategory").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::RuntimeType for AudioRenderCategory {
-    const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Media.Render.AudioRenderCategory;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
+impl ::windows::core::RuntimeType for AudioRenderCategory {
+    const SIGNATURE: ::windows::imp::ConstBuffer = ::windows::imp::ConstBuffer::from_slice(b"enum(Windows.Media.Render.AudioRenderCategory;i4)");
 }
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
