@@ -1,5 +1,3 @@
-#[cfg(feature = "Services_Cortana")]
-pub mod Cortana;
 #[cfg(feature = "Services_Maps")]
 pub mod Maps;
 #[cfg(feature = "Services_Store")]
