@@ -3,33 +3,28 @@
 pub struct ID2D1SimplifiedGeometrySink(::windows::core::IUnknown);
 impl ID2D1SimplifiedGeometrySink {
     pub unsafe fn SetFillMode(&self, fillmode: D2D1_FILL_MODE) {
-        (::windows::core::Vtable::vtable(self).SetFillMode)(::windows::core::Vtable::as_raw(self), fillmode)
+        (::windows::core::Interface::vtable(self).SetFillMode)(::windows::core::Interface::as_raw(self), fillmode)
     }
     pub unsafe fn SetSegmentFlags(&self, vertexflags: D2D1_PATH_SEGMENT) {
-        (::windows::core::Vtable::vtable(self).SetSegmentFlags)(::windows::core::Vtable::as_raw(self), vertexflags)
+        (::windows::core::Interface::vtable(self).SetSegmentFlags)(::windows::core::Interface::as_raw(self), vertexflags)
     }
     pub unsafe fn BeginFigure(&self, startpoint: D2D_POINT_2F, figurebegin: D2D1_FIGURE_BEGIN) {
-        (::windows::core::Vtable::vtable(self).BeginFigure)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(startpoint), figurebegin)
+        (::windows::core::Interface::vtable(self).BeginFigure)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(startpoint), figurebegin)
     }
     pub unsafe fn AddLines(&self, points: &[D2D_POINT_2F]) {
-        (::windows::core::Vtable::vtable(self).AddLines)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(points.as_ptr()), points.len() as _)
+        (::windows::core::Interface::vtable(self).AddLines)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(points.as_ptr()), points.len() as _)
     }
     pub unsafe fn AddBeziers(&self, beziers: &[D2D1_BEZIER_SEGMENT]) {
-        (::windows::core::Vtable::vtable(self).AddBeziers)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(beziers.as_ptr()), beziers.len() as _)
+        (::windows::core::Interface::vtable(self).AddBeziers)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(beziers.as_ptr()), beziers.len() as _)
     }
     pub unsafe fn EndFigure(&self, figureend: D2D1_FIGURE_END) {
-        (::windows::core::Vtable::vtable(self).EndFigure)(::windows::core::Vtable::as_raw(self), figureend)
+        (::windows::core::Interface::vtable(self).EndFigure)(::windows::core::Interface::as_raw(self), figureend)
     }
     pub unsafe fn Close(&self) -> ::windows::core::Result<()> {
-        (::windows::core::Vtable::vtable(self).Close)(::windows::core::Vtable::as_raw(self)).ok()
-    }
-}
-::windows::core::interface_hierarchy!(ID2D1SimplifiedGeometrySink, ::windows::core::IUnknown);
-impl ::core::clone::Clone for ID2D1SimplifiedGeometrySink {
-    fn clone(&self) -> Self {
-        Self(self.0.clone())
+        (::windows::core::Interface::vtable(self).Close)(::windows::core::Interface::as_raw(self)).ok()
     }
 }
+::windows::imp::interface_hierarchy!(ID2D1SimplifiedGeometrySink, ::windows::core::IUnknown);
 impl ::core::cmp::PartialEq for ID2D1SimplifiedGeometrySink {
     fn eq(&self, other: &Self) -> bool {
         self.0 == other.0
@@ -43,10 +38,15 @@ impl ::core::fmt::Debug for ID2D1SimplifiedGeometrySink {
 }
 unsafe impl ::core::marker::Send for ID2D1SimplifiedGeometrySink {}
 unsafe impl ::core::marker::Sync for ID2D1SimplifiedGeometrySink {}
-unsafe impl ::windows::core::Vtable for ID2D1SimplifiedGeometrySink {
+unsafe impl ::windows::core::Interface for ID2D1SimplifiedGeometrySink {
     type Vtable = ID2D1SimplifiedGeometrySink_Vtbl;
 }
-unsafe impl ::windows::core::Interface for ID2D1SimplifiedGeometrySink {
+impl ::core::clone::Clone for ID2D1SimplifiedGeometrySink {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+unsafe impl ::windows::core::ComInterface for ID2D1SimplifiedGeometrySink {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x2cd9069e_12e2_11dc_9fed_001143a055f9);
 }
 #[repr(C)]
@@ -90,8 +90,8 @@ impl ::core::default::Default for D2D1_2DAFFINETRANSFORM_INTERPOLATION_MODE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_2DAFFINETRANSFORM_INTERPOLATION_MODE {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_2DAFFINETRANSFORM_INTERPOLATION_MODE {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_2DAFFINETRANSFORM_INTERPOLATION_MODE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -123,8 +123,8 @@ impl ::core::default::Default for D2D1_ALPHA_MODE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_ALPHA_MODE {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_ALPHA_MODE {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_ALPHA_MODE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -200,8 +200,8 @@ impl ::core::default::Default for D2D1_BLEND_MODE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_BLEND_MODE {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_BLEND_MODE {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_BLEND_MODE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -229,8 +229,8 @@ impl ::core::default::Default for D2D1_BORDER_MODE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_BORDER_MODE {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_BORDER_MODE {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_BORDER_MODE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -258,8 +258,8 @@ impl ::core::default::Default for D2D1_COLORMATRIX_ALPHA_MODE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_COLORMATRIX_ALPHA_MODE {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_COLORMATRIX_ALPHA_MODE {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_COLORMATRIX_ALPHA_MODE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -309,8 +309,8 @@ impl ::core::default::Default for D2D1_COMPOSITE_MODE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_COMPOSITE_MODE {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_COMPOSITE_MODE {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_COMPOSITE_MODE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -338,8 +338,8 @@ impl ::core::default::Default for D2D1_FIGURE_BEGIN {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_FIGURE_BEGIN {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_FIGURE_BEGIN {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_FIGURE_BEGIN {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -367,8 +367,8 @@ impl ::core::default::Default for D2D1_FIGURE_END {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_FIGURE_END {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_FIGURE_END {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_FIGURE_END {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -396,8 +396,8 @@ impl ::core::default::Default for D2D1_FILL_MODE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_FILL_MODE {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_FILL_MODE {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_FILL_MODE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -427,14 +427,19 @@ impl ::core::default::Default for D2D1_PATH_SEGMENT {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_PATH_SEGMENT {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_PATH_SEGMENT {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_PATH_SEGMENT {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_tuple("D2D1_PATH_SEGMENT").field(&self.0).finish()
     }
 }
+impl D2D1_PATH_SEGMENT {
+    pub const fn contains(&self, other: Self) -> bool {
+        self.0 & other.0 == other.0
+    }
+}
 impl ::core::ops::BitOr for D2D1_PATH_SEGMENT {
     type Output = Self;
     fn bitor(self, other: Self) -> Self {
@@ -484,8 +489,8 @@ impl ::core::default::Default for D2D1_TURBULENCE_NOISE {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_TURBULENCE_NOISE {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_TURBULENCE_NOISE {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for D2D1_TURBULENCE_NOISE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
@@ -510,12 +515,12 @@ impl ::core::fmt::Debug for D2D1_BEZIER_SEGMENT {
         f.debug_struct("D2D1_BEZIER_SEGMENT").field("point1", &self.point1).field("point2", &self.point2).field("point3", &self.point3).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_BEZIER_SEGMENT {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_BEZIER_SEGMENT {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D1_BEZIER_SEGMENT {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D1_BEZIER_SEGMENT>()) == 0 }
+        self.point1 == other.point1 && self.point2 == other.point2 && self.point3 == other.point3
     }
 }
 impl ::core::cmp::Eq for D2D1_BEZIER_SEGMENT {}
@@ -543,12 +548,12 @@ impl ::core::fmt::Debug for D2D1_COLOR_F {
         f.debug_struct("D2D1_COLOR_F").field("r", &self.r).field("g", &self.g).field("b", &self.b).field("a", &self.a).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D1_COLOR_F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_COLOR_F {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D1_COLOR_F {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D1_COLOR_F>()) == 0 }
+        self.r == other.r && self.g == other.g && self.b == other.b && self.a == other.a
     }
 }
 impl ::core::cmp::Eq for D2D1_COLOR_F {}
@@ -579,13 +584,13 @@ impl ::core::fmt::Debug for D2D1_PIXEL_FORMAT {
     }
 }
 #[cfg(feature = "Win32_Graphics_Dxgi_Common")]
-unsafe impl ::windows::core::Abi for D2D1_PIXEL_FORMAT {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D1_PIXEL_FORMAT {
+    type TypeKind = ::windows::core::CopyType;
 }
 #[cfg(feature = "Win32_Graphics_Dxgi_Common")]
 impl ::core::cmp::PartialEq for D2D1_PIXEL_FORMAT {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D1_PIXEL_FORMAT>()) == 0 }
+        self.format == other.format && self.alphaMode == other.alphaMode
     }
 }
 #[cfg(feature = "Win32_Graphics_Dxgi_Common")]
@@ -615,12 +620,12 @@ impl ::core::fmt::Debug for D2D_COLOR_F {
         f.debug_struct("D2D_COLOR_F").field("r", &self.r).field("g", &self.g).field("b", &self.b).field("a", &self.a).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_COLOR_F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_COLOR_F {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_COLOR_F {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_COLOR_F>()) == 0 }
+        self.r == other.r && self.g == other.g && self.b == other.b && self.a == other.a
     }
 }
 impl ::core::cmp::Eq for D2D_COLOR_F {}
@@ -631,128 +636,6 @@ impl ::core::default::Default for D2D_COLOR_F {
 }
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Graphics_Direct2D_Common\"`*"]
-pub struct D2D_MATRIX_3X2_F {
-    pub Anonymous: D2D_MATRIX_3X2_F_0,
-}
-impl ::core::marker::Copy for D2D_MATRIX_3X2_F {}
-impl ::core::clone::Clone for D2D_MATRIX_3X2_F {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-unsafe impl ::windows::core::Abi for D2D_MATRIX_3X2_F {
-    type Abi = Self;
-}
-impl ::core::cmp::PartialEq for D2D_MATRIX_3X2_F {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_3X2_F>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_3X2_F {}
-impl ::core::default::Default for D2D_MATRIX_3X2_F {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
-#[repr(C)]
-#[doc = "*Required features: `\"Win32_Graphics_Direct2D_Common\"`*"]
-pub union D2D_MATRIX_3X2_F_0 {
-    pub Anonymous1: D2D_MATRIX_3X2_F_0_0,
-    pub Anonymous2: D2D_MATRIX_3X2_F_0_1,
-    pub m: [f32; 6],
-}
-impl ::core::marker::Copy for D2D_MATRIX_3X2_F_0 {}
-impl ::core::clone::Clone for D2D_MATRIX_3X2_F_0 {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-unsafe impl ::windows::core::Abi for D2D_MATRIX_3X2_F_0 {
-    type Abi = Self;
-}
-impl ::core::cmp::PartialEq for D2D_MATRIX_3X2_F_0 {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_3X2_F_0>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_3X2_F_0 {}
-impl ::core::default::Default for D2D_MATRIX_3X2_F_0 {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
-#[repr(C)]
-#[doc = "*Required features: `\"Win32_Graphics_Direct2D_Common\"`*"]
-pub struct D2D_MATRIX_3X2_F_0_0 {
-    pub m11: f32,
-    pub m12: f32,
-    pub m21: f32,
-    pub m22: f32,
-    pub dx: f32,
-    pub dy: f32,
-}
-impl ::core::marker::Copy for D2D_MATRIX_3X2_F_0_0 {}
-impl ::core::clone::Clone for D2D_MATRIX_3X2_F_0_0 {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::fmt::Debug for D2D_MATRIX_3X2_F_0_0 {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_struct("D2D_MATRIX_3X2_F_0_0").field("m11", &self.m11).field("m12", &self.m12).field("m21", &self.m21).field("m22", &self.m22).field("dx", &self.dx).field("dy", &self.dy).finish()
-    }
-}
-unsafe impl ::windows::core::Abi for D2D_MATRIX_3X2_F_0_0 {
-    type Abi = Self;
-}
-impl ::core::cmp::PartialEq for D2D_MATRIX_3X2_F_0_0 {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_3X2_F_0_0>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_3X2_F_0_0 {}
-impl ::core::default::Default for D2D_MATRIX_3X2_F_0_0 {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
-#[repr(C)]
-#[doc = "*Required features: `\"Win32_Graphics_Direct2D_Common\"`*"]
-pub struct D2D_MATRIX_3X2_F_0_1 {
-    pub _11: f32,
-    pub _12: f32,
-    pub _21: f32,
-    pub _22: f32,
-    pub _31: f32,
-    pub _32: f32,
-}
-impl ::core::marker::Copy for D2D_MATRIX_3X2_F_0_1 {}
-impl ::core::clone::Clone for D2D_MATRIX_3X2_F_0_1 {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::fmt::Debug for D2D_MATRIX_3X2_F_0_1 {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_struct("D2D_MATRIX_3X2_F_0_1").field("_11", &self._11).field("_12", &self._12).field("_21", &self._21).field("_22", &self._22).field("_31", &self._31).field("_32", &self._32).finish()
-    }
-}
-unsafe impl ::windows::core::Abi for D2D_MATRIX_3X2_F_0_1 {
-    type Abi = Self;
-}
-impl ::core::cmp::PartialEq for D2D_MATRIX_3X2_F_0_1 {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_3X2_F_0_1>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_3X2_F_0_1 {}
-impl ::core::default::Default for D2D_MATRIX_3X2_F_0_1 {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
-#[repr(C)]
-#[doc = "*Required features: `\"Win32_Graphics_Direct2D_Common\"`*"]
 pub struct D2D_MATRIX_4X3_F {
     pub Anonymous: D2D_MATRIX_4X3_F_0,
 }
@@ -762,15 +645,9 @@ impl ::core::clone::Clone for D2D_MATRIX_4X3_F {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_4X3_F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_4X3_F {
+    type TypeKind = ::windows::core::CopyType;
 }
-impl ::core::cmp::PartialEq for D2D_MATRIX_4X3_F {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_4X3_F>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_4X3_F {}
 impl ::core::default::Default for D2D_MATRIX_4X3_F {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -788,15 +665,9 @@ impl ::core::clone::Clone for D2D_MATRIX_4X3_F_0 {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_4X3_F_0 {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_4X3_F_0 {
+    type TypeKind = ::windows::core::CopyType;
 }
-impl ::core::cmp::PartialEq for D2D_MATRIX_4X3_F_0 {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_4X3_F_0>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_4X3_F_0 {}
 impl ::core::default::Default for D2D_MATRIX_4X3_F_0 {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -829,12 +700,12 @@ impl ::core::fmt::Debug for D2D_MATRIX_4X3_F_0_0 {
         f.debug_struct("D2D_MATRIX_4X3_F_0_0").field("_11", &self._11).field("_12", &self._12).field("_13", &self._13).field("_21", &self._21).field("_22", &self._22).field("_23", &self._23).field("_31", &self._31).field("_32", &self._32).field("_33", &self._33).field("_41", &self._41).field("_42", &self._42).field("_43", &self._43).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_4X3_F_0_0 {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_4X3_F_0_0 {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_MATRIX_4X3_F_0_0 {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_4X3_F_0_0>()) == 0 }
+        self._11 == other._11 && self._12 == other._12 && self._13 == other._13 && self._21 == other._21 && self._22 == other._22 && self._23 == other._23 && self._31 == other._31 && self._32 == other._32 && self._33 == other._33 && self._41 == other._41 && self._42 == other._42 && self._43 == other._43
     }
 }
 impl ::core::cmp::Eq for D2D_MATRIX_4X3_F_0_0 {}
@@ -854,15 +725,9 @@ impl ::core::clone::Clone for D2D_MATRIX_4X4_F {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_4X4_F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_4X4_F {
+    type TypeKind = ::windows::core::CopyType;
 }
-impl ::core::cmp::PartialEq for D2D_MATRIX_4X4_F {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_4X4_F>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_4X4_F {}
 impl ::core::default::Default for D2D_MATRIX_4X4_F {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -880,15 +745,9 @@ impl ::core::clone::Clone for D2D_MATRIX_4X4_F_0 {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_4X4_F_0 {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_4X4_F_0 {
+    type TypeKind = ::windows::core::CopyType;
 }
-impl ::core::cmp::PartialEq for D2D_MATRIX_4X4_F_0 {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_4X4_F_0>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_4X4_F_0 {}
 impl ::core::default::Default for D2D_MATRIX_4X4_F_0 {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -925,12 +784,12 @@ impl ::core::fmt::Debug for D2D_MATRIX_4X4_F_0_0 {
         f.debug_struct("D2D_MATRIX_4X4_F_0_0").field("_11", &self._11).field("_12", &self._12).field("_13", &self._13).field("_14", &self._14).field("_21", &self._21).field("_22", &self._22).field("_23", &self._23).field("_24", &self._24).field("_31", &self._31).field("_32", &self._32).field("_33", &self._33).field("_34", &self._34).field("_41", &self._41).field("_42", &self._42).field("_43", &self._43).field("_44", &self._44).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_4X4_F_0_0 {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_4X4_F_0_0 {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_MATRIX_4X4_F_0_0 {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_4X4_F_0_0>()) == 0 }
+        self._11 == other._11 && self._12 == other._12 && self._13 == other._13 && self._14 == other._14 && self._21 == other._21 && self._22 == other._22 && self._23 == other._23 && self._24 == other._24 && self._31 == other._31 && self._32 == other._32 && self._33 == other._33 && self._34 == other._34 && self._41 == other._41 && self._42 == other._42 && self._43 == other._43 && self._44 == other._44
     }
 }
 impl ::core::cmp::Eq for D2D_MATRIX_4X4_F_0_0 {}
@@ -950,15 +809,9 @@ impl ::core::clone::Clone for D2D_MATRIX_5X4_F {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_5X4_F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_5X4_F {
+    type TypeKind = ::windows::core::CopyType;
 }
-impl ::core::cmp::PartialEq for D2D_MATRIX_5X4_F {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_5X4_F>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_5X4_F {}
 impl ::core::default::Default for D2D_MATRIX_5X4_F {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -976,15 +829,9 @@ impl ::core::clone::Clone for D2D_MATRIX_5X4_F_0 {
         *self
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_5X4_F_0 {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_5X4_F_0 {
+    type TypeKind = ::windows::core::CopyType;
 }
-impl ::core::cmp::PartialEq for D2D_MATRIX_5X4_F_0 {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_5X4_F_0>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for D2D_MATRIX_5X4_F_0 {}
 impl ::core::default::Default for D2D_MATRIX_5X4_F_0 {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
@@ -1046,12 +893,12 @@ impl ::core::fmt::Debug for D2D_MATRIX_5X4_F_0_0 {
             .finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_MATRIX_5X4_F_0_0 {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_MATRIX_5X4_F_0_0 {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_MATRIX_5X4_F_0_0 {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_MATRIX_5X4_F_0_0>()) == 0 }
+        self._11 == other._11 && self._12 == other._12 && self._13 == other._13 && self._14 == other._14 && self._21 == other._21 && self._22 == other._22 && self._23 == other._23 && self._24 == other._24 && self._31 == other._31 && self._32 == other._32 && self._33 == other._33 && self._34 == other._34 && self._41 == other._41 && self._42 == other._42 && self._43 == other._43 && self._44 == other._44 && self._51 == other._51 && self._52 == other._52 && self._53 == other._53 && self._54 == other._54
     }
 }
 impl ::core::cmp::Eq for D2D_MATRIX_5X4_F_0_0 {}
@@ -1077,12 +924,12 @@ impl ::core::fmt::Debug for D2D_POINT_2F {
         f.debug_struct("D2D_POINT_2F").field("x", &self.x).field("y", &self.y).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_POINT_2F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_POINT_2F {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_POINT_2F {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_POINT_2F>()) == 0 }
+        self.x == other.x && self.y == other.y
     }
 }
 impl ::core::cmp::Eq for D2D_POINT_2F {}
@@ -1108,12 +955,12 @@ impl ::core::fmt::Debug for D2D_POINT_2U {
         f.debug_struct("D2D_POINT_2U").field("x", &self.x).field("y", &self.y).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_POINT_2U {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_POINT_2U {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_POINT_2U {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_POINT_2U>()) == 0 }
+        self.x == other.x && self.y == other.y
     }
 }
 impl ::core::cmp::Eq for D2D_POINT_2U {}
@@ -1141,12 +988,12 @@ impl ::core::fmt::Debug for D2D_RECT_F {
         f.debug_struct("D2D_RECT_F").field("left", &self.left).field("top", &self.top).field("right", &self.right).field("bottom", &self.bottom).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_RECT_F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_RECT_F {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_RECT_F {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_RECT_F>()) == 0 }
+        self.left == other.left && self.top == other.top && self.right == other.right && self.bottom == other.bottom
     }
 }
 impl ::core::cmp::Eq for D2D_RECT_F {}
@@ -1174,12 +1021,12 @@ impl ::core::fmt::Debug for D2D_RECT_U {
         f.debug_struct("D2D_RECT_U").field("left", &self.left).field("top", &self.top).field("right", &self.right).field("bottom", &self.bottom).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_RECT_U {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_RECT_U {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_RECT_U {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_RECT_U>()) == 0 }
+        self.left == other.left && self.top == other.top && self.right == other.right && self.bottom == other.bottom
     }
 }
 impl ::core::cmp::Eq for D2D_RECT_U {}
@@ -1205,12 +1052,12 @@ impl ::core::fmt::Debug for D2D_SIZE_F {
         f.debug_struct("D2D_SIZE_F").field("width", &self.width).field("height", &self.height).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_SIZE_F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_SIZE_F {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_SIZE_F {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_SIZE_F>()) == 0 }
+        self.width == other.width && self.height == other.height
     }
 }
 impl ::core::cmp::Eq for D2D_SIZE_F {}
@@ -1236,12 +1083,12 @@ impl ::core::fmt::Debug for D2D_SIZE_U {
         f.debug_struct("D2D_SIZE_U").field("width", &self.width).field("height", &self.height).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_SIZE_U {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_SIZE_U {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_SIZE_U {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_SIZE_U>()) == 0 }
+        self.width == other.width && self.height == other.height
     }
 }
 impl ::core::cmp::Eq for D2D_SIZE_U {}
@@ -1267,12 +1114,12 @@ impl ::core::fmt::Debug for D2D_VECTOR_2F {
         f.debug_struct("D2D_VECTOR_2F").field("x", &self.x).field("y", &self.y).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_VECTOR_2F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_VECTOR_2F {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_VECTOR_2F {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_VECTOR_2F>()) == 0 }
+        self.x == other.x && self.y == other.y
     }
 }
 impl ::core::cmp::Eq for D2D_VECTOR_2F {}
@@ -1299,12 +1146,12 @@ impl ::core::fmt::Debug for D2D_VECTOR_3F {
         f.debug_struct("D2D_VECTOR_3F").field("x", &self.x).field("y", &self.y).field("z", &self.z).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_VECTOR_3F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_VECTOR_3F {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_VECTOR_3F {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_VECTOR_3F>()) == 0 }
+        self.x == other.x && self.y == other.y && self.z == other.z
     }
 }
 impl ::core::cmp::Eq for D2D_VECTOR_3F {}
@@ -1332,12 +1179,12 @@ impl ::core::fmt::Debug for D2D_VECTOR_4F {
         f.debug_struct("D2D_VECTOR_4F").field("x", &self.x).field("y", &self.y).field("z", &self.z).field("w", &self.w).finish()
     }
 }
-unsafe impl ::windows::core::Abi for D2D_VECTOR_4F {
-    type Abi = Self;
+impl ::windows::core::TypeKind for D2D_VECTOR_4F {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for D2D_VECTOR_4F {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<D2D_VECTOR_4F>()) == 0 }
+        self.x == other.x && self.y == other.y && self.z == other.z && self.w == other.w
     }
 }
 impl ::core::cmp::Eq for D2D_VECTOR_4F {}
