@@ -2,14 +2,11 @@
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn Netbios(pncb: *mut NCB) -> u8 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Netbios(pncb: *mut NCB) -> u8;
-    }
-    Netbios(::core::mem::transmute(pncb))
+    ::windows_targets::link ! ( "netapi32.dll""system" fn Netbios ( pncb : *mut NCB ) -> u8 );
+    Netbios(pncb)
 }
 #[doc = "*Required features: `\"Win32_NetworkManagement_NetBios\"`*"]
-pub const ALL_TRANSPORTS: ::windows::core::PCSTR = ::windows::s!("M\u{0}\u{0}\u{0}");
+pub const ALL_TRANSPORTS: ::windows::core::PCSTR = ::windows::core::s!("M\u{0}\u{0}\u{0}");
 #[doc = "*Required features: `\"Win32_NetworkManagement_NetBios\"`*"]
 pub const ASYNCH: u32 = 128u32;
 #[doc = "*Required features: `\"Win32_NetworkManagement_NetBios\"`*"]
@@ -31,7 +28,7 @@ pub const LISTEN_OUTSTANDING: u32 = 1u32;
 #[doc = "*Required features: `\"Win32_NetworkManagement_NetBios\"`*"]
 pub const MAX_LANA: u32 = 254u32;
 #[doc = "*Required features: `\"Win32_NetworkManagement_NetBios\"`*"]
-pub const MS_NBF: ::windows::core::PCSTR = ::windows::s!("MNBF");
+pub const MS_NBF: ::windows::core::PCSTR = ::windows::core::s!("MNBF");
 #[doc = "*Required features: `\"Win32_NetworkManagement_NetBios\"`*"]
 pub const NAME_FLAGS_MASK: u32 = 135u32;
 #[doc = "*Required features: `\"Win32_NetworkManagement_NetBios\"`*"]
@@ -194,12 +191,12 @@ impl ::core::fmt::Debug for ACTION_HEADER {
         f.debug_struct("ACTION_HEADER").field("transport_id", &self.transport_id).field("action_code", &self.action_code).field("reserved", &self.reserved).finish()
     }
 }
-unsafe impl ::windows::core::Abi for ACTION_HEADER {
-    type Abi = Self;
+impl ::windows::core::TypeKind for ACTION_HEADER {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for ACTION_HEADER {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<ACTION_HEADER>()) == 0 }
+        self.transport_id == other.transport_id && self.action_code == other.action_code && self.reserved == other.reserved
     }
 }
 impl ::core::cmp::Eq for ACTION_HEADER {}
@@ -278,12 +275,38 @@ impl ::core::fmt::Debug for ADAPTER_STATUS {
             .finish()
     }
 }
-unsafe impl ::windows::core::Abi for ADAPTER_STATUS {
-    type Abi = Self;
+impl ::windows::core::TypeKind for ADAPTER_STATUS {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for ADAPTER_STATUS {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<ADAPTER_STATUS>()) == 0 }
+        self.adapter_address == other.adapter_address
+            && self.rev_major == other.rev_major
+            && self.reserved0 == other.reserved0
+            && self.adapter_type == other.adapter_type
+            && self.rev_minor == other.rev_minor
+            && self.duration == other.duration
+            && self.frmr_recv == other.frmr_recv
+            && self.frmr_xmit == other.frmr_xmit
+            && self.iframe_recv_err == other.iframe_recv_err
+            && self.xmit_aborts == other.xmit_aborts
+            && self.xmit_success == other.xmit_success
+            && self.recv_success == other.recv_success
+            && self.iframe_xmit_err == other.iframe_xmit_err
+            && self.recv_buff_unavail == other.recv_buff_unavail
+            && self.t1_timeouts == other.t1_timeouts
+            && self.ti_timeouts == other.ti_timeouts
+            && self.reserved1 == other.reserved1
+            && self.free_ncbs == other.free_ncbs
+            && self.max_cfg_ncbs == other.max_cfg_ncbs
+            && self.max_ncbs == other.max_ncbs
+            && self.xmit_buf_unavail == other.xmit_buf_unavail
+            && self.max_dgram_size == other.max_dgram_size
+            && self.pending_sess == other.pending_sess
+            && self.max_cfg_sess == other.max_cfg_sess
+            && self.max_sess == other.max_sess
+            && self.max_sess_pkt_size == other.max_sess_pkt_size
+            && self.name_count == other.name_count
     }
 }
 impl ::core::cmp::Eq for ADAPTER_STATUS {}
@@ -313,12 +336,12 @@ impl ::core::fmt::Debug for FIND_NAME_BUFFER {
         f.debug_struct("FIND_NAME_BUFFER").field("length", &self.length).field("access_control", &self.access_control).field("frame_control", &self.frame_control).field("destination_addr", &self.destination_addr).field("source_addr", &self.source_addr).field("routing_info", &self.routing_info).finish()
     }
 }
-unsafe impl ::windows::core::Abi for FIND_NAME_BUFFER {
-    type Abi = Self;
+impl ::windows::core::TypeKind for FIND_NAME_BUFFER {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for FIND_NAME_BUFFER {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<FIND_NAME_BUFFER>()) == 0 }
+        self.length == other.length && self.access_control == other.access_control && self.frame_control == other.frame_control && self.destination_addr == other.destination_addr && self.source_addr == other.source_addr && self.routing_info == other.routing_info
     }
 }
 impl ::core::cmp::Eq for FIND_NAME_BUFFER {}
@@ -345,12 +368,12 @@ impl ::core::fmt::Debug for FIND_NAME_HEADER {
         f.debug_struct("FIND_NAME_HEADER").field("node_count", &self.node_count).field("reserved", &self.reserved).field("unique_group", &self.unique_group).finish()
     }
 }
-unsafe impl ::windows::core::Abi for FIND_NAME_HEADER {
-    type Abi = Self;
+impl ::windows::core::TypeKind for FIND_NAME_HEADER {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for FIND_NAME_HEADER {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<FIND_NAME_HEADER>()) == 0 }
+        self.node_count == other.node_count && self.reserved == other.reserved && self.unique_group == other.unique_group
     }
 }
 impl ::core::cmp::Eq for FIND_NAME_HEADER {}
@@ -376,12 +399,12 @@ impl ::core::fmt::Debug for LANA_ENUM {
         f.debug_struct("LANA_ENUM").field("length", &self.length).field("lana", &self.lana).finish()
     }
 }
-unsafe impl ::windows::core::Abi for LANA_ENUM {
-    type Abi = Self;
+impl ::windows::core::TypeKind for LANA_ENUM {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for LANA_ENUM {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<LANA_ENUM>()) == 0 }
+        self.length == other.length && self.lana == other.lana
     }
 }
 impl ::core::cmp::Eq for LANA_ENUM {}
@@ -408,12 +431,12 @@ impl ::core::fmt::Debug for NAME_BUFFER {
         f.debug_struct("NAME_BUFFER").field("name", &self.name).field("name_num", &self.name_num).field("name_flags", &self.name_flags).finish()
     }
 }
-unsafe impl ::windows::core::Abi for NAME_BUFFER {
-    type Abi = Self;
+impl ::windows::core::TypeKind for NAME_BUFFER {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for NAME_BUFFER {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<NAME_BUFFER>()) == 0 }
+        self.name == other.name && self.name_num == other.name_num && self.name_flags == other.name_flags
     }
 }
 impl ::core::cmp::Eq for NAME_BUFFER {}
@@ -478,14 +501,14 @@ impl ::core::fmt::Debug for NCB {
 }
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 #[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for NCB {
-    type Abi = Self;
+impl ::windows::core::TypeKind for NCB {
+    type TypeKind = ::windows::core::CopyType;
 }
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for NCB {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<NCB>()) == 0 }
+        self.ncb_command == other.ncb_command && self.ncb_retcode == other.ncb_retcode && self.ncb_lsn == other.ncb_lsn && self.ncb_num == other.ncb_num && self.ncb_buffer == other.ncb_buffer && self.ncb_length == other.ncb_length && self.ncb_callname == other.ncb_callname && self.ncb_name == other.ncb_name && self.ncb_rto == other.ncb_rto && self.ncb_sto == other.ncb_sto && self.ncb_post == other.ncb_post && self.ncb_lana_num == other.ncb_lana_num && self.ncb_cmd_cplt == other.ncb_cmd_cplt && self.ncb_reserve == other.ncb_reserve && self.ncb_event == other.ncb_event
     }
 }
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
@@ -554,14 +577,14 @@ impl ::core::fmt::Debug for NCB {
 }
 #[cfg(target_arch = "x86")]
 #[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for NCB {
-    type Abi = Self;
+impl ::windows::core::TypeKind for NCB {
+    type TypeKind = ::windows::core::CopyType;
 }
 #[cfg(target_arch = "x86")]
 #[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for NCB {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<NCB>()) == 0 }
+        self.ncb_command == other.ncb_command && self.ncb_retcode == other.ncb_retcode && self.ncb_lsn == other.ncb_lsn && self.ncb_num == other.ncb_num && self.ncb_buffer == other.ncb_buffer && self.ncb_length == other.ncb_length && self.ncb_callname == other.ncb_callname && self.ncb_name == other.ncb_name && self.ncb_rto == other.ncb_rto && self.ncb_sto == other.ncb_sto && self.ncb_post == other.ncb_post && self.ncb_lana_num == other.ncb_lana_num && self.ncb_cmd_cplt == other.ncb_cmd_cplt && self.ncb_reserve == other.ncb_reserve && self.ncb_event == other.ncb_event
     }
 }
 #[cfg(target_arch = "x86")]
@@ -595,12 +618,12 @@ impl ::core::fmt::Debug for SESSION_BUFFER {
         f.debug_struct("SESSION_BUFFER").field("lsn", &self.lsn).field("state", &self.state).field("local_name", &self.local_name).field("remote_name", &self.remote_name).field("rcvs_outstanding", &self.rcvs_outstanding).field("sends_outstanding", &self.sends_outstanding).finish()
     }
 }
-unsafe impl ::windows::core::Abi for SESSION_BUFFER {
-    type Abi = Self;
+impl ::windows::core::TypeKind for SESSION_BUFFER {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for SESSION_BUFFER {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<SESSION_BUFFER>()) == 0 }
+        self.lsn == other.lsn && self.state == other.state && self.local_name == other.local_name && self.remote_name == other.remote_name && self.rcvs_outstanding == other.rcvs_outstanding && self.sends_outstanding == other.sends_outstanding
     }
 }
 impl ::core::cmp::Eq for SESSION_BUFFER {}
@@ -628,12 +651,12 @@ impl ::core::fmt::Debug for SESSION_HEADER {
         f.debug_struct("SESSION_HEADER").field("sess_name", &self.sess_name).field("num_sess", &self.num_sess).field("rcv_dg_outstanding", &self.rcv_dg_outstanding).field("rcv_any_outstanding", &self.rcv_any_outstanding).finish()
     }
 }
-unsafe impl ::windows::core::Abi for SESSION_HEADER {
-    type Abi = Self;
+impl ::windows::core::TypeKind for SESSION_HEADER {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for SESSION_HEADER {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<SESSION_HEADER>()) == 0 }
+        self.sess_name == other.sess_name && self.num_sess == other.num_sess && self.rcv_dg_outstanding == other.rcv_dg_outstanding && self.rcv_any_outstanding == other.rcv_any_outstanding
     }
 }
 impl ::core::cmp::Eq for SESSION_HEADER {}
