@@ -1,3 +1,4 @@
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"implement\"`*"]
 pub trait IFindSimilarResults_Impl: Sized {
     fn GetSize(&self) -> ::windows::core::Result<u32>;
     fn GetNextFileId(&self, numtraitsmatched: *mut u32, similarityfileid: *mut SimilarityFileId) -> ::windows::core::Result<()>;
@@ -28,9 +29,10 @@ impl IFindSimilarResults_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IFindSimilarResults as ::windows::core::Interface>::IID
+        iid == &<IFindSimilarResults as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait IRdcComparator_Impl: Sized {
     fn Process(&self, endofinput: super::super::Foundation::BOOL, endofoutput: *mut super::super::Foundation::BOOL, inputbuffer: *mut RdcBufferPointer, outputbuffer: *mut RdcNeedPointer, rdc_errorcode: *mut RDC_ErrorCode) -> ::windows::core::Result<()>;
@@ -48,9 +50,10 @@ impl IRdcComparator_Vtbl {
         Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), Process: Process::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcComparator as ::windows::core::Interface>::IID
+        iid == &<IRdcComparator as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait IRdcFileReader_Impl: Sized {
     fn GetFileSize(&self) -> ::windows::core::Result<u64>;
@@ -97,9 +100,10 @@ impl IRdcFileReader_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcFileReader as ::windows::core::Interface>::IID
+        iid == &<IRdcFileReader as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait IRdcFileWriter_Impl: Sized + IRdcFileReader_Impl {
     fn Write(&self, offsetfilestart: u64, bytestowrite: u32) -> ::windows::core::Result<u8>;
@@ -140,9 +144,10 @@ impl IRdcFileWriter_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcFileWriter as ::windows::core::Interface>::IID || iid == &<IRdcFileReader as ::windows::core::Interface>::IID
+        iid == &<IRdcFileWriter as ::windows::core::ComInterface>::IID || iid == &<IRdcFileReader as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait IRdcGenerator_Impl: Sized {
     fn GetGeneratorParameters(&self, level: u32) -> ::windows::core::Result<IRdcGeneratorParameters>;
@@ -176,9 +181,10 @@ impl IRdcGenerator_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcGenerator as ::windows::core::Interface>::IID
+        iid == &<IRdcGenerator as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"implement\"`*"]
 pub trait IRdcGeneratorFilterMaxParameters_Impl: Sized {
     fn GetHorizonSize(&self) -> ::windows::core::Result<u32>;
     fn SetHorizonSize(&self, horizonsize: u32) -> ::windows::core::Result<()>;
@@ -229,9 +235,10 @@ impl IRdcGeneratorFilterMaxParameters_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcGeneratorFilterMaxParameters as ::windows::core::Interface>::IID
+        iid == &<IRdcGeneratorFilterMaxParameters as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"implement\"`*"]
 pub trait IRdcGeneratorParameters_Impl: Sized {
     fn GetGeneratorParametersType(&self) -> ::windows::core::Result<GeneratorParametersType>;
     fn GetParametersVersion(&self, currentversion: *mut u32, minimumcompatibleappversion: *mut u32) -> ::windows::core::Result<()>;
@@ -282,16 +289,17 @@ impl IRdcGeneratorParameters_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcGeneratorParameters as ::windows::core::Interface>::IID
+        iid == &<IRdcGeneratorParameters as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"implement\"`*"]
 pub trait IRdcLibrary_Impl: Sized {
     fn ComputeDefaultRecursionDepth(&self, filesize: u64) -> ::windows::core::Result<u32>;
     fn CreateGeneratorParameters(&self, parameterstype: GeneratorParametersType, level: u32) -> ::windows::core::Result<IRdcGeneratorParameters>;
     fn OpenGeneratorParameters(&self, size: u32, parametersblob: *const u8) -> ::windows::core::Result<IRdcGeneratorParameters>;
     fn CreateGenerator(&self, depth: u32, igeneratorparametersarray: *const ::core::option::Option<IRdcGeneratorParameters>) -> ::windows::core::Result<IRdcGenerator>;
-    fn CreateComparator(&self, iseedsignaturesfile: &::core::option::Option<IRdcFileReader>, comparatorbuffersize: u32) -> ::windows::core::Result<IRdcComparator>;
-    fn CreateSignatureReader(&self, ifilereader: &::core::option::Option<IRdcFileReader>) -> ::windows::core::Result<IRdcSignatureReader>;
+    fn CreateComparator(&self, iseedsignaturesfile: ::core::option::Option<&IRdcFileReader>, comparatorbuffersize: u32) -> ::windows::core::Result<IRdcComparator>;
+    fn CreateSignatureReader(&self, ifilereader: ::core::option::Option<&IRdcFileReader>) -> ::windows::core::Result<IRdcSignatureReader>;
     fn GetRDCVersion(&self, currentversion: *mut u32, minimumcompatibleappversion: *mut u32) -> ::windows::core::Result<()>;
 }
 impl ::windows::core::RuntimeName for IRdcLibrary {}
@@ -344,7 +352,7 @@ impl IRdcLibrary_Vtbl {
         unsafe extern "system" fn CreateComparator<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IRdcLibrary_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, iseedsignaturesfile: *mut ::core::ffi::c_void, comparatorbuffersize: u32, icomparator: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            match this.CreateComparator(::core::mem::transmute(&iseedsignaturesfile), ::core::mem::transmute_copy(&comparatorbuffersize)) {
+            match this.CreateComparator(::windows::core::from_raw_borrowed(&iseedsignaturesfile), ::core::mem::transmute_copy(&comparatorbuffersize)) {
                 ::core::result::Result::Ok(ok__) => {
                     ::core::ptr::write(icomparator, ::core::mem::transmute(ok__));
                     ::windows::core::HRESULT(0)
@@ -355,7 +363,7 @@ impl IRdcLibrary_Vtbl {
         unsafe extern "system" fn CreateSignatureReader<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IRdcLibrary_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, ifilereader: *mut ::core::ffi::c_void, isignaturereader: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            match this.CreateSignatureReader(::core::mem::transmute(&ifilereader)) {
+            match this.CreateSignatureReader(::windows::core::from_raw_borrowed(&ifilereader)) {
                 ::core::result::Result::Ok(ok__) => {
                     ::core::ptr::write(isignaturereader, ::core::mem::transmute(ok__));
                     ::windows::core::HRESULT(0)
@@ -380,9 +388,10 @@ impl IRdcLibrary_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcLibrary as ::windows::core::Interface>::IID
+        iid == &<IRdcLibrary as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait IRdcSignatureReader_Impl: Sized {
     fn ReadHeader(&self) -> ::windows::core::Result<RDC_ErrorCode>;
@@ -416,9 +425,10 @@ impl IRdcSignatureReader_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcSignatureReader as ::windows::core::Interface>::IID
+        iid == &<IRdcSignatureReader as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"implement\"`*"]
 pub trait IRdcSimilarityGenerator_Impl: Sized {
     fn EnableSimilarity(&self) -> ::windows::core::Result<()>;
     fn Results(&self) -> ::windows::core::Result<SimilarityData>;
@@ -449,17 +459,18 @@ impl IRdcSimilarityGenerator_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<IRdcSimilarityGenerator as ::windows::core::Interface>::IID
+        iid == &<IRdcSimilarityGenerator as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait ISimilarity_Impl: Sized {
     fn CreateTable(&self, path: &::windows::core::PCWSTR, truncate: super::super::Foundation::BOOL, securitydescriptor: *const u8, recordsize: u32) -> ::windows::core::Result<RdcCreatedTables>;
-    fn CreateTableIndirect(&self, mapping: &::core::option::Option<ISimilarityTraitsMapping>, fileidfile: &::core::option::Option<IRdcFileWriter>, truncate: super::super::Foundation::BOOL, recordsize: u32) -> ::windows::core::Result<RdcCreatedTables>;
+    fn CreateTableIndirect(&self, mapping: ::core::option::Option<&ISimilarityTraitsMapping>, fileidfile: ::core::option::Option<&IRdcFileWriter>, truncate: super::super::Foundation::BOOL, recordsize: u32) -> ::windows::core::Result<RdcCreatedTables>;
     fn CloseTable(&self, isvalid: super::super::Foundation::BOOL) -> ::windows::core::Result<()>;
     fn Append(&self, similarityfileid: *const SimilarityFileId, similaritydata: *const SimilarityData) -> ::windows::core::Result<()>;
     fn FindSimilarFileId(&self, similaritydata: *const SimilarityData, numberofmatchesrequired: u16, resultssize: u32) -> ::windows::core::Result<IFindSimilarResults>;
-    fn CopyAndSwap(&self, newsimilaritytables: &::core::option::Option<ISimilarity>, reportprogress: &::core::option::Option<ISimilarityReportProgress>) -> ::windows::core::Result<()>;
+    fn CopyAndSwap(&self, newsimilaritytables: ::core::option::Option<&ISimilarity>, reportprogress: ::core::option::Option<&ISimilarityReportProgress>) -> ::windows::core::Result<()>;
     fn GetRecordCount(&self) -> ::windows::core::Result<u32>;
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -481,7 +492,7 @@ impl ISimilarity_Vtbl {
         unsafe extern "system" fn CreateTableIndirect<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: ISimilarity_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, mapping: *mut ::core::ffi::c_void, fileidfile: *mut ::core::ffi::c_void, truncate: super::super::Foundation::BOOL, recordsize: u32, isnew: *mut RdcCreatedTables) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            match this.CreateTableIndirect(::core::mem::transmute(&mapping), ::core::mem::transmute(&fileidfile), ::core::mem::transmute_copy(&truncate), ::core::mem::transmute_copy(&recordsize)) {
+            match this.CreateTableIndirect(::windows::core::from_raw_borrowed(&mapping), ::windows::core::from_raw_borrowed(&fileidfile), ::core::mem::transmute_copy(&truncate), ::core::mem::transmute_copy(&recordsize)) {
                 ::core::result::Result::Ok(ok__) => {
                     ::core::ptr::write(isnew, ::core::mem::transmute(ok__));
                     ::windows::core::HRESULT(0)
@@ -513,7 +524,7 @@ impl ISimilarity_Vtbl {
         unsafe extern "system" fn CopyAndSwap<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: ISimilarity_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, newsimilaritytables: *mut ::core::ffi::c_void, reportprogress: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            this.CopyAndSwap(::core::mem::transmute(&newsimilaritytables), ::core::mem::transmute(&reportprogress)).into()
+            this.CopyAndSwap(::windows::core::from_raw_borrowed(&newsimilaritytables), ::windows::core::from_raw_borrowed(&reportprogress)).into()
         }
         unsafe extern "system" fn GetRecordCount<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: ISimilarity_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, recordcount: *mut u32) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
@@ -538,16 +549,17 @@ impl ISimilarity_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<ISimilarity as ::windows::core::Interface>::IID
+        iid == &<ISimilarity as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait ISimilarityFileIdTable_Impl: Sized {
     fn CreateTable(&self, path: &::windows::core::PCWSTR, truncate: super::super::Foundation::BOOL, securitydescriptor: *const u8, recordsize: u32) -> ::windows::core::Result<RdcCreatedTables>;
-    fn CreateTableIndirect(&self, fileidfile: &::core::option::Option<IRdcFileWriter>, truncate: super::super::Foundation::BOOL, recordsize: u32) -> ::windows::core::Result<RdcCreatedTables>;
+    fn CreateTableIndirect(&self, fileidfile: ::core::option::Option<&IRdcFileWriter>, truncate: super::super::Foundation::BOOL, recordsize: u32) -> ::windows::core::Result<RdcCreatedTables>;
     fn CloseTable(&self, isvalid: super::super::Foundation::BOOL) -> ::windows::core::Result<()>;
     fn Append(&self, similarityfileid: *const SimilarityFileId) -> ::windows::core::Result<u32>;
-    fn Lookup(&self, similarityfileindex: u32) -> ::windows::core::Result<SimilarityFileId>;
+    fn Lookup(&self, similarityfileindex: u32, similarityfileid: *mut SimilarityFileId) -> ::windows::core::Result<()>;
     fn Invalidate(&self, similarityfileindex: u32) -> ::windows::core::Result<()>;
     fn GetRecordCount(&self) -> ::windows::core::Result<u32>;
 }
@@ -570,7 +582,7 @@ impl ISimilarityFileIdTable_Vtbl {
         unsafe extern "system" fn CreateTableIndirect<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: ISimilarityFileIdTable_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, fileidfile: *mut ::core::ffi::c_void, truncate: super::super::Foundation::BOOL, recordsize: u32, isnew: *mut RdcCreatedTables) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            match this.CreateTableIndirect(::core::mem::transmute(&fileidfile), ::core::mem::transmute_copy(&truncate), ::core::mem::transmute_copy(&recordsize)) {
+            match this.CreateTableIndirect(::windows::core::from_raw_borrowed(&fileidfile), ::core::mem::transmute_copy(&truncate), ::core::mem::transmute_copy(&recordsize)) {
                 ::core::result::Result::Ok(ok__) => {
                     ::core::ptr::write(isnew, ::core::mem::transmute(ok__));
                     ::windows::core::HRESULT(0)
@@ -597,13 +609,7 @@ impl ISimilarityFileIdTable_Vtbl {
         unsafe extern "system" fn Lookup<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: ISimilarityFileIdTable_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, similarityfileindex: u32, similarityfileid: *mut SimilarityFileId) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            match this.Lookup(::core::mem::transmute_copy(&similarityfileindex)) {
-                ::core::result::Result::Ok(ok__) => {
-                    ::core::ptr::write(similarityfileid, ::core::mem::transmute(ok__));
-                    ::windows::core::HRESULT(0)
-                }
-                ::core::result::Result::Err(err) => err.into(),
-            }
+            this.Lookup(::core::mem::transmute_copy(&similarityfileindex), ::core::mem::transmute_copy(&similarityfileid)).into()
         }
         unsafe extern "system" fn Invalidate<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: ISimilarityFileIdTable_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, similarityfileindex: u32) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
@@ -633,9 +639,10 @@ impl ISimilarityFileIdTable_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<ISimilarityFileIdTable as ::windows::core::Interface>::IID
+        iid == &<ISimilarityFileIdTable as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"implement\"`*"]
 pub trait ISimilarityReportProgress_Impl: Sized {
     fn ReportProgress(&self, percentcompleted: u32) -> ::windows::core::Result<()>;
 }
@@ -650,9 +657,10 @@ impl ISimilarityReportProgress_Vtbl {
         Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), ReportProgress: ReportProgress::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<ISimilarityReportProgress as ::windows::core::Interface>::IID
+        iid == &<ISimilarityReportProgress as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait ISimilarityTableDumpState_Impl: Sized {
     fn GetNextData(&self, resultssize: u32, resultsused: *mut u32, eof: *mut super::super::Foundation::BOOL, results: *mut SimilarityDumpData) -> ::windows::core::Result<()>;
@@ -670,9 +678,10 @@ impl ISimilarityTableDumpState_Vtbl {
         Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), GetNextData: GetNextData::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<ISimilarityTableDumpState as ::windows::core::Interface>::IID
+        iid == &<ISimilarityTableDumpState as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait ISimilarityTraitsMappedView_Impl: Sized {
     fn Flush(&self) -> ::windows::core::Result<()>;
@@ -720,16 +729,17 @@ impl ISimilarityTraitsMappedView_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<ISimilarityTraitsMappedView as ::windows::core::Interface>::IID
+        iid == &<ISimilarityTraitsMappedView as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"implement\"`*"]
 pub trait ISimilarityTraitsMapping_Impl: Sized {
     fn CloseMapping(&self);
     fn SetFileSize(&self, filesize: u64) -> ::windows::core::Result<()>;
     fn GetFileSize(&self) -> ::windows::core::Result<u64>;
     fn OpenMapping(&self, accessmode: RdcMappingAccessMode, begin: u64, end: u64) -> ::windows::core::Result<u64>;
     fn ResizeMapping(&self, accessmode: RdcMappingAccessMode, begin: u64, end: u64) -> ::windows::core::Result<u64>;
-    fn GetPageSize(&self, pagesize: *mut u32);
+    fn GetPageSize(&self, pagesize: *mut u32) -> ();
     fn CreateView(&self, minimummappedpages: u32, accessmode: RdcMappingAccessMode) -> ::windows::core::Result<ISimilarityTraitsMappedView>;
 }
 impl ::windows::core::RuntimeName for ISimilarityTraitsMapping {}
@@ -806,13 +816,14 @@ impl ISimilarityTraitsMapping_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<ISimilarityTraitsMapping as ::windows::core::Interface>::IID
+        iid == &<ISimilarityTraitsMapping as ::windows::core::ComInterface>::IID
     }
 }
+#[doc = "*Required features: `\"Win32_Networking_RemoteDifferentialCompression\"`, `\"Win32_Foundation\"`, `\"implement\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub trait ISimilarityTraitsTable_Impl: Sized {
     fn CreateTable(&self, path: &::windows::core::PCWSTR, truncate: super::super::Foundation::BOOL, securitydescriptor: *const u8) -> ::windows::core::Result<RdcCreatedTables>;
-    fn CreateTableIndirect(&self, mapping: &::core::option::Option<ISimilarityTraitsMapping>, truncate: super::super::Foundation::BOOL) -> ::windows::core::Result<RdcCreatedTables>;
+    fn CreateTableIndirect(&self, mapping: ::core::option::Option<&ISimilarityTraitsMapping>, truncate: super::super::Foundation::BOOL) -> ::windows::core::Result<RdcCreatedTables>;
     fn CloseTable(&self, isvalid: super::super::Foundation::BOOL) -> ::windows::core::Result<()>;
     fn Append(&self, data: *const SimilarityData, fileindex: u32) -> ::windows::core::Result<()>;
     fn FindSimilarFileIndex(&self, similaritydata: *const SimilarityData, numberofmatchesrequired: u16, findsimilarfileindexresults: *mut FindSimilarFileIndexResults, resultssize: u32, resultsused: *mut u32) -> ::windows::core::Result<()>;
@@ -838,7 +849,7 @@ impl ISimilarityTraitsTable_Vtbl {
         unsafe extern "system" fn CreateTableIndirect<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: ISimilarityTraitsTable_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, mapping: *mut ::core::ffi::c_void, truncate: super::super::Foundation::BOOL, isnew: *mut RdcCreatedTables) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
-            match this.CreateTableIndirect(::core::mem::transmute(&mapping), ::core::mem::transmute_copy(&truncate)) {
+            match this.CreateTableIndirect(::windows::core::from_raw_borrowed(&mapping), ::core::mem::transmute_copy(&truncate)) {
                 ::core::result::Result::Ok(ok__) => {
                     ::core::ptr::write(isnew, ::core::mem::transmute(ok__));
                     ::windows::core::HRESULT(0)
@@ -895,6 +906,6 @@ impl ISimilarityTraitsTable_Vtbl {
         }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
-        iid == &<ISimilarityTraitsTable as ::windows::core::Interface>::IID
+        iid == &<ISimilarityTraitsTable as ::windows::core::ComInterface>::IID
     }
 }
