@@ -2,21 +2,15 @@
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn OperationEnd(operationendparams: *const OPERATION_END_PARAMETERS) -> super::super::Foundation::BOOL {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn OperationEnd(operationendparams: *const OPERATION_END_PARAMETERS) -> super::super::Foundation::BOOL;
-    }
-    OperationEnd(::core::mem::transmute(operationendparams))
+    ::windows_targets::link ! ( "advapi32.dll""system" fn OperationEnd ( operationendparams : *const OPERATION_END_PARAMETERS ) -> super::super::Foundation:: BOOL );
+    OperationEnd(operationendparams)
 }
 #[doc = "*Required features: `\"Win32_Storage_OperationRecorder\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn OperationStart(operationstartparams: *const OPERATION_START_PARAMETERS) -> super::super::Foundation::BOOL {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn OperationStart(operationstartparams: *const OPERATION_START_PARAMETERS) -> super::super::Foundation::BOOL;
-    }
-    OperationStart(::core::mem::transmute(operationstartparams))
+    ::windows_targets::link ! ( "advapi32.dll""system" fn OperationStart ( operationstartparams : *const OPERATION_START_PARAMETERS ) -> super::super::Foundation:: BOOL );
+    OperationStart(operationstartparams)
 }
 #[doc = "*Required features: `\"Win32_Storage_OperationRecorder\"`*"]
 #[repr(transparent)]
@@ -35,14 +29,19 @@ impl ::core::default::Default for OPERATION_END_PARAMETERS_FLAGS {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for OPERATION_END_PARAMETERS_FLAGS {
-    type Abi = Self;
+impl ::windows::core::TypeKind for OPERATION_END_PARAMETERS_FLAGS {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for OPERATION_END_PARAMETERS_FLAGS {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_tuple("OPERATION_END_PARAMETERS_FLAGS").field(&self.0).finish()
     }
 }
+impl OPERATION_END_PARAMETERS_FLAGS {
+    pub const fn contains(&self, other: Self) -> bool {
+        self.0 & other.0 == other.0
+    }
+}
 impl ::core::ops::BitOr for OPERATION_END_PARAMETERS_FLAGS {
     type Output = Self;
     fn bitor(self, other: Self) -> Self {
@@ -88,14 +87,19 @@ impl ::core::default::Default for OPERATION_START_FLAGS {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for OPERATION_START_FLAGS {
-    type Abi = Self;
+impl ::windows::core::TypeKind for OPERATION_START_FLAGS {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for OPERATION_START_FLAGS {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_tuple("OPERATION_START_FLAGS").field(&self.0).finish()
     }
 }
+impl OPERATION_START_FLAGS {
+    pub const fn contains(&self, other: Self) -> bool {
+        self.0 & other.0 == other.0
+    }
+}
 impl ::core::ops::BitOr for OPERATION_START_FLAGS {
     type Output = Self;
     fn bitor(self, other: Self) -> Self {
@@ -142,12 +146,12 @@ impl ::core::fmt::Debug for OPERATION_END_PARAMETERS {
         f.debug_struct("OPERATION_END_PARAMETERS").field("Version", &self.Version).field("OperationId", &self.OperationId).field("Flags", &self.Flags).finish()
     }
 }
-unsafe impl ::windows::core::Abi for OPERATION_END_PARAMETERS {
-    type Abi = Self;
+impl ::windows::core::TypeKind for OPERATION_END_PARAMETERS {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for OPERATION_END_PARAMETERS {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<OPERATION_END_PARAMETERS>()) == 0 }
+        self.Version == other.Version && self.OperationId == other.OperationId && self.Flags == other.Flags
     }
 }
 impl ::core::cmp::Eq for OPERATION_END_PARAMETERS {}
@@ -174,12 +178,12 @@ impl ::core::fmt::Debug for OPERATION_START_PARAMETERS {
         f.debug_struct("OPERATION_START_PARAMETERS").field("Version", &self.Version).field("OperationId", &self.OperationId).field("Flags", &self.Flags).finish()
     }
 }
-unsafe impl ::windows::core::Abi for OPERATION_START_PARAMETERS {
-    type Abi = Self;
+impl ::windows::core::TypeKind for OPERATION_START_PARAMETERS {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::cmp::PartialEq for OPERATION_START_PARAMETERS {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<OPERATION_START_PARAMETERS>()) == 0 }
+        self.Version == other.Version && self.OperationId == other.OperationId && self.Flags == other.Flags
     }
 }
 impl ::core::cmp::Eq for OPERATION_START_PARAMETERS {}
