@@ -1,5 +1,5 @@
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct HCS_CALLBACK(pub isize);
 impl HCS_CALLBACK {
     pub fn is_invalid(&self) -> bool {
@@ -22,8 +22,8 @@ impl ::core::fmt::Debug for HCS_CALLBACK {
         f.debug_tuple("HCS_CALLBACK").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Abi for HCS_CALLBACK {
-    type Abi = Self;
+impl ::windows::core::TypeKind for HCS_CALLBACK {
+    type TypeKind = ::windows::core::CopyType;
 }
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
