@@ -1,42 +1,176 @@
 #[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn AbortSystemShutdownA<'a, P0>(lpmachinename: P0) -> super::super::Foundation::BOOL
+pub unsafe fn AbortSystemShutdownA<P0>(lpmachinename: P0) -> super::super::Foundation::BOOL
 where
-    P0: ::std::convert::Into<::windows::core::PCSTR>,
+    P0: ::windows::core::IntoParam<::windows::core::PCSTR>,
 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn AbortSystemShutdownA(lpmachinename: ::windows::core::PCSTR) -> super::super::Foundation::BOOL;
-    }
-    AbortSystemShutdownA(lpmachinename.into())
+    ::windows_targets::link ! ( "advapi32.dll""system" fn AbortSystemShutdownA ( lpmachinename : ::windows::core::PCSTR ) -> super::super::Foundation:: BOOL );
+    AbortSystemShutdownA(lpmachinename.into_param().abi())
 }
 #[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn AbortSystemShutdownW<'a, P0>(lpmachinename: P0) -> super::super::Foundation::BOOL
+pub unsafe fn AbortSystemShutdownW<P0>(lpmachinename: P0) -> super::super::Foundation::BOOL
 where
-    P0: ::std::convert::Into<::windows::core::PCWSTR>,
+    P0: ::windows::core::IntoParam<::windows::core::PCWSTR>,
 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn AbortSystemShutdownW(lpmachinename: ::windows::core::PCWSTR) -> super::super::Foundation::BOOL;
-    }
-    AbortSystemShutdownW(lpmachinename.into())
+    ::windows_targets::link ! ( "advapi32.dll""system" fn AbortSystemShutdownW ( lpmachinename : ::windows::core::PCWSTR ) -> super::super::Foundation:: BOOL );
+    AbortSystemShutdownW(lpmachinename.into_param().abi())
 }
 #[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn CheckForHiberboot<'a, P0>(phiberboot: *mut super::super::Foundation::BOOLEAN, bclearflag: P0) -> u32
+pub unsafe fn CheckForHiberboot<P0>(phiberboot: *mut super::super::Foundation::BOOLEAN, bclearflag: P0) -> u32
 where
-    P0: ::std::convert::Into<super::super::Foundation::BOOLEAN>,
+    P0: ::windows::core::IntoParam<super::super::Foundation::BOOLEAN>,
 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn CheckForHiberboot(phiberboot: *mut super::super::Foundation::BOOLEAN, bclearflag: super::super::Foundation::BOOLEAN) -> u32;
-    }
-    CheckForHiberboot(::core::mem::transmute(phiberboot), bclearflag.into())
+    ::windows_targets::link ! ( "advapi32.dll""system" fn CheckForHiberboot ( phiberboot : *mut super::super::Foundation:: BOOLEAN , bclearflag : super::super::Foundation:: BOOLEAN ) -> u32 );
+    CheckForHiberboot(phiberboot, bclearflag.into_param().abi())
 }
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn ExitWindowsEx(uflags: EXIT_WINDOWS_FLAGS, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL {
+    ::windows_targets::link ! ( "user32.dll""system" fn ExitWindowsEx ( uflags : EXIT_WINDOWS_FLAGS , dwreason : SHUTDOWN_REASON ) -> super::super::Foundation:: BOOL );
+    ExitWindowsEx(uflags, dwreason)
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+#[inline]
+pub unsafe fn InitiateShutdownA<P0, P1>(lpmachinename: P0, lpmessage: P1, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32
+where
+    P0: ::windows::core::IntoParam<::windows::core::PCSTR>,
+    P1: ::windows::core::IntoParam<::windows::core::PCSTR>,
+{
+    ::windows_targets::link ! ( "advapi32.dll""system" fn InitiateShutdownA ( lpmachinename : ::windows::core::PCSTR , lpmessage : ::windows::core::PCSTR , dwgraceperiod : u32 , dwshutdownflags : SHUTDOWN_FLAGS , dwreason : SHUTDOWN_REASON ) -> u32 );
+    InitiateShutdownA(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), dwgraceperiod, dwshutdownflags, dwreason)
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+#[inline]
+pub unsafe fn InitiateShutdownW<P0, P1>(lpmachinename: P0, lpmessage: P1, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32
+where
+    P0: ::windows::core::IntoParam<::windows::core::PCWSTR>,
+    P1: ::windows::core::IntoParam<::windows::core::PCWSTR>,
+{
+    ::windows_targets::link ! ( "advapi32.dll""system" fn InitiateShutdownW ( lpmachinename : ::windows::core::PCWSTR , lpmessage : ::windows::core::PCWSTR , dwgraceperiod : u32 , dwshutdownflags : SHUTDOWN_FLAGS , dwreason : SHUTDOWN_REASON ) -> u32 );
+    InitiateShutdownW(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), dwgraceperiod, dwshutdownflags, dwreason)
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn InitiateSystemShutdownA<P0, P1, P2, P3>(lpmachinename: P0, lpmessage: P1, dwtimeout: u32, bforceappsclosed: P2, brebootaftershutdown: P3) -> super::super::Foundation::BOOL
+where
+    P0: ::windows::core::IntoParam<::windows::core::PCSTR>,
+    P1: ::windows::core::IntoParam<::windows::core::PCSTR>,
+    P2: ::windows::core::IntoParam<super::super::Foundation::BOOL>,
+    P3: ::windows::core::IntoParam<super::super::Foundation::BOOL>,
+{
+    ::windows_targets::link ! ( "advapi32.dll""system" fn InitiateSystemShutdownA ( lpmachinename : ::windows::core::PCSTR , lpmessage : ::windows::core::PCSTR , dwtimeout : u32 , bforceappsclosed : super::super::Foundation:: BOOL , brebootaftershutdown : super::super::Foundation:: BOOL ) -> super::super::Foundation:: BOOL );
+    InitiateSystemShutdownA(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), dwtimeout, bforceappsclosed.into_param().abi(), brebootaftershutdown.into_param().abi())
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn InitiateSystemShutdownExA<P0, P1, P2, P3>(lpmachinename: P0, lpmessage: P1, dwtimeout: u32, bforceappsclosed: P2, brebootaftershutdown: P3, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL
+where
+    P0: ::windows::core::IntoParam<::windows::core::PCSTR>,
+    P1: ::windows::core::IntoParam<::windows::core::PCSTR>,
+    P2: ::windows::core::IntoParam<super::super::Foundation::BOOL>,
+    P3: ::windows::core::IntoParam<super::super::Foundation::BOOL>,
+{
+    ::windows_targets::link ! ( "advapi32.dll""system" fn InitiateSystemShutdownExA ( lpmachinename : ::windows::core::PCSTR , lpmessage : ::windows::core::PCSTR , dwtimeout : u32 , bforceappsclosed : super::super::Foundation:: BOOL , brebootaftershutdown : super::super::Foundation:: BOOL , dwreason : SHUTDOWN_REASON ) -> super::super::Foundation:: BOOL );
+    InitiateSystemShutdownExA(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), dwtimeout, bforceappsclosed.into_param().abi(), brebootaftershutdown.into_param().abi(), dwreason)
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn InitiateSystemShutdownExW<P0, P1, P2, P3>(lpmachinename: P0, lpmessage: P1, dwtimeout: u32, bforceappsclosed: P2, brebootaftershutdown: P3, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL
+where
+    P0: ::windows::core::IntoParam<::windows::core::PCWSTR>,
+    P1: ::windows::core::IntoParam<::windows::core::PCWSTR>,
+    P2: ::windows::core::IntoParam<super::super::Foundation::BOOL>,
+    P3: ::windows::core::IntoParam<super::super::Foundation::BOOL>,
+{
+    ::windows_targets::link ! ( "advapi32.dll""system" fn InitiateSystemShutdownExW ( lpmachinename : ::windows::core::PCWSTR , lpmessage : ::windows::core::PCWSTR , dwtimeout : u32 , bforceappsclosed : super::super::Foundation:: BOOL , brebootaftershutdown : super::super::Foundation:: BOOL , dwreason : SHUTDOWN_REASON ) -> super::super::Foundation:: BOOL );
+    InitiateSystemShutdownExW(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), dwtimeout, bforceappsclosed.into_param().abi(), brebootaftershutdown.into_param().abi(), dwreason)
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn InitiateSystemShutdownW<P0, P1, P2, P3>(lpmachinename: P0, lpmessage: P1, dwtimeout: u32, bforceappsclosed: P2, brebootaftershutdown: P3) -> super::super::Foundation::BOOL
+where
+    P0: ::windows::core::IntoParam<::windows::core::PCWSTR>,
+    P1: ::windows::core::IntoParam<::windows::core::PCWSTR>,
+    P2: ::windows::core::IntoParam<super::super::Foundation::BOOL>,
+    P3: ::windows::core::IntoParam<super::super::Foundation::BOOL>,
+{
+    ::windows_targets::link ! ( "advapi32.dll""system" fn InitiateSystemShutdownW ( lpmachinename : ::windows::core::PCWSTR , lpmessage : ::windows::core::PCWSTR , dwtimeout : u32 , bforceappsclosed : super::super::Foundation:: BOOL , brebootaftershutdown : super::super::Foundation:: BOOL ) -> super::super::Foundation:: BOOL );
+    InitiateSystemShutdownW(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), dwtimeout, bforceappsclosed.into_param().abi(), brebootaftershutdown.into_param().abi())
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn LockWorkStation() -> super::super::Foundation::BOOL {
+    ::windows_targets::link ! ( "user32.dll""system" fn LockWorkStation ( ) -> super::super::Foundation:: BOOL );
+    LockWorkStation()
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn ShutdownBlockReasonCreate<P0, P1>(hwnd: P0, pwszreason: P1) -> super::super::Foundation::BOOL
+where
+    P0: ::windows::core::IntoParam<super::super::Foundation::HWND>,
+    P1: ::windows::core::IntoParam<::windows::core::PCWSTR>,
+{
+    ::windows_targets::link ! ( "user32.dll""system" fn ShutdownBlockReasonCreate ( hwnd : super::super::Foundation:: HWND , pwszreason : ::windows::core::PCWSTR ) -> super::super::Foundation:: BOOL );
+    ShutdownBlockReasonCreate(hwnd.into_param().abi(), pwszreason.into_param().abi())
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn ShutdownBlockReasonDestroy<P0>(hwnd: P0) -> super::super::Foundation::BOOL
+where
+    P0: ::windows::core::IntoParam<super::super::Foundation::HWND>,
+{
+    ::windows_targets::link ! ( "user32.dll""system" fn ShutdownBlockReasonDestroy ( hwnd : super::super::Foundation:: HWND ) -> super::super::Foundation:: BOOL );
+    ShutdownBlockReasonDestroy(hwnd.into_param().abi())
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn ShutdownBlockReasonQuery<P0>(hwnd: P0, pwszbuff: ::windows::core::PWSTR, pcchbuff: *mut u32) -> super::super::Foundation::BOOL
+where
+    P0: ::windows::core::IntoParam<super::super::Foundation::HWND>,
+{
+    ::windows_targets::link ! ( "user32.dll""system" fn ShutdownBlockReasonQuery ( hwnd : super::super::Foundation:: HWND , pwszbuff : ::windows::core::PWSTR , pcchbuff : *mut u32 ) -> super::super::Foundation:: BOOL );
+    ShutdownBlockReasonQuery(hwnd.into_param().abi(), ::core::mem::transmute(pwszbuff), pcchbuff)
+}
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const MAX_NUM_REASONS: u32 = 256u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const MAX_REASON_BUGID_LEN: u32 = 32u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const MAX_REASON_COMMENT_LEN: u32 = 512u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const MAX_REASON_DESC_LEN: u32 = 256u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const MAX_REASON_NAME_LEN: u32 = 64u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const POLICY_SHOWREASONUI_ALWAYS: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const POLICY_SHOWREASONUI_NEVER: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const POLICY_SHOWREASONUI_SERVERONLY: u32 = 3u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const POLICY_SHOWREASONUI_WORKSTATIONONLY: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const SHUTDOWN_TYPE_LEN: u32 = 32u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const SNAPSHOT_POLICY_ALWAYS: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const SNAPSHOT_POLICY_NEVER: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
+pub const SNAPSHOT_POLICY_UNPLANNED: u32 = 2u32;
 #[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
@@ -64,142 +198,14 @@ impl ::core::default::Default for EXIT_WINDOWS_FLAGS {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for EXIT_WINDOWS_FLAGS {
-    type Abi = Self;
+impl ::windows::core::TypeKind for EXIT_WINDOWS_FLAGS {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for EXIT_WINDOWS_FLAGS {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_tuple("EXIT_WINDOWS_FLAGS").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn ExitWindowsEx(uflags: EXIT_WINDOWS_FLAGS, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn ExitWindowsEx(uflags: EXIT_WINDOWS_FLAGS, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL;
-    }
-    ExitWindowsEx(uflags, dwreason)
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-#[inline]
-pub unsafe fn InitiateShutdownA<'a, P0, P1>(lpmachinename: P0, lpmessage: P1, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32
-where
-    P0: ::std::convert::Into<::windows::core::PCSTR>,
-    P1: ::std::convert::Into<::windows::core::PCSTR>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn InitiateShutdownA(lpmachinename: ::windows::core::PCSTR, lpmessage: ::windows::core::PCSTR, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32;
-    }
-    InitiateShutdownA(lpmachinename.into(), lpmessage.into(), dwgraceperiod, dwshutdownflags, dwreason)
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-#[inline]
-pub unsafe fn InitiateShutdownW<'a, P0, P1>(lpmachinename: P0, lpmessage: P1, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32
-where
-    P0: ::std::convert::Into<::windows::core::PCWSTR>,
-    P1: ::std::convert::Into<::windows::core::PCWSTR>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn InitiateShutdownW(lpmachinename: ::windows::core::PCWSTR, lpmessage: ::windows::core::PCWSTR, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32;
-    }
-    InitiateShutdownW(lpmachinename.into(), lpmessage.into(), dwgraceperiod, dwshutdownflags, dwreason)
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn InitiateSystemShutdownA<'a, P0, P1, P2, P3>(lpmachinename: P0, lpmessage: P1, dwtimeout: u32, bforceappsclosed: P2, brebootaftershutdown: P3) -> super::super::Foundation::BOOL
-where
-    P0: ::std::convert::Into<::windows::core::PCSTR>,
-    P1: ::std::convert::Into<::windows::core::PCSTR>,
-    P2: ::std::convert::Into<super::super::Foundation::BOOL>,
-    P3: ::std::convert::Into<super::super::Foundation::BOOL>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn InitiateSystemShutdownA(lpmachinename: ::windows::core::PCSTR, lpmessage: ::windows::core::PCSTR, dwtimeout: u32, bforceappsclosed: super::super::Foundation::BOOL, brebootaftershutdown: super::super::Foundation::BOOL) -> super::super::Foundation::BOOL;
-    }
-    InitiateSystemShutdownA(lpmachinename.into(), lpmessage.into(), dwtimeout, bforceappsclosed.into(), brebootaftershutdown.into())
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn InitiateSystemShutdownExA<'a, P0, P1, P2, P3>(lpmachinename: P0, lpmessage: P1, dwtimeout: u32, bforceappsclosed: P2, brebootaftershutdown: P3, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL
-where
-    P0: ::std::convert::Into<::windows::core::PCSTR>,
-    P1: ::std::convert::Into<::windows::core::PCSTR>,
-    P2: ::std::convert::Into<super::super::Foundation::BOOL>,
-    P3: ::std::convert::Into<super::super::Foundation::BOOL>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn InitiateSystemShutdownExA(lpmachinename: ::windows::core::PCSTR, lpmessage: ::windows::core::PCSTR, dwtimeout: u32, bforceappsclosed: super::super::Foundation::BOOL, brebootaftershutdown: super::super::Foundation::BOOL, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL;
-    }
-    InitiateSystemShutdownExA(lpmachinename.into(), lpmessage.into(), dwtimeout, bforceappsclosed.into(), brebootaftershutdown.into(), dwreason)
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn InitiateSystemShutdownExW<'a, P0, P1, P2, P3>(lpmachinename: P0, lpmessage: P1, dwtimeout: u32, bforceappsclosed: P2, brebootaftershutdown: P3, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL
-where
-    P0: ::std::convert::Into<::windows::core::PCWSTR>,
-    P1: ::std::convert::Into<::windows::core::PCWSTR>,
-    P2: ::std::convert::Into<super::super::Foundation::BOOL>,
-    P3: ::std::convert::Into<super::super::Foundation::BOOL>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn InitiateSystemShutdownExW(lpmachinename: ::windows::core::PCWSTR, lpmessage: ::windows::core::PCWSTR, dwtimeout: u32, bforceappsclosed: super::super::Foundation::BOOL, brebootaftershutdown: super::super::Foundation::BOOL, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL;
-    }
-    InitiateSystemShutdownExW(lpmachinename.into(), lpmessage.into(), dwtimeout, bforceappsclosed.into(), brebootaftershutdown.into(), dwreason)
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn InitiateSystemShutdownW<'a, P0, P1, P2, P3>(lpmachinename: P0, lpmessage: P1, dwtimeout: u32, bforceappsclosed: P2, brebootaftershutdown: P3) -> super::super::Foundation::BOOL
-where
-    P0: ::std::convert::Into<::windows::core::PCWSTR>,
-    P1: ::std::convert::Into<::windows::core::PCWSTR>,
-    P2: ::std::convert::Into<super::super::Foundation::BOOL>,
-    P3: ::std::convert::Into<super::super::Foundation::BOOL>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn InitiateSystemShutdownW(lpmachinename: ::windows::core::PCWSTR, lpmessage: ::windows::core::PCWSTR, dwtimeout: u32, bforceappsclosed: super::super::Foundation::BOOL, brebootaftershutdown: super::super::Foundation::BOOL) -> super::super::Foundation::BOOL;
-    }
-    InitiateSystemShutdownW(lpmachinename.into(), lpmessage.into(), dwtimeout, bforceappsclosed.into(), brebootaftershutdown.into())
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn LockWorkStation() -> super::super::Foundation::BOOL {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn LockWorkStation() -> super::super::Foundation::BOOL;
-    }
-    LockWorkStation()
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const MAX_NUM_REASONS: u32 = 256u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const MAX_REASON_BUGID_LEN: u32 = 32u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const MAX_REASON_COMMENT_LEN: u32 = 512u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const MAX_REASON_DESC_LEN: u32 = 256u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const MAX_REASON_NAME_LEN: u32 = 64u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const POLICY_SHOWREASONUI_ALWAYS: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const POLICY_SHOWREASONUI_NEVER: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const POLICY_SHOWREASONUI_SERVERONLY: u32 = 3u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const POLICY_SHOWREASONUI_WORKSTATIONONLY: u32 = 2u32;
 #[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
@@ -249,14 +255,19 @@ impl ::core::default::Default for SHUTDOWN_FLAGS {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for SHUTDOWN_FLAGS {
-    type Abi = Self;
+impl ::windows::core::TypeKind for SHUTDOWN_FLAGS {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for SHUTDOWN_FLAGS {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_tuple("SHUTDOWN_FLAGS").field(&self.0).finish()
     }
 }
+impl SHUTDOWN_FLAGS {
+    pub const fn contains(&self, other: Self) -> bool {
+        self.0 & other.0 == other.0
+    }
+}
 impl ::core::ops::BitOr for SHUTDOWN_FLAGS {
     type Output = Self;
     fn bitor(self, other: Self) -> Self {
@@ -402,14 +413,19 @@ impl ::core::default::Default for SHUTDOWN_REASON {
         Self(0)
     }
 }
-unsafe impl ::windows::core::Abi for SHUTDOWN_REASON {
-    type Abi = Self;
+impl ::windows::core::TypeKind for SHUTDOWN_REASON {
+    type TypeKind = ::windows::core::CopyType;
 }
 impl ::core::fmt::Debug for SHUTDOWN_REASON {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_tuple("SHUTDOWN_REASON").field(&self.0).finish()
     }
 }
+impl SHUTDOWN_REASON {
+    pub const fn contains(&self, other: Self) -> bool {
+        self.0 & other.0 == other.0
+    }
+}
 impl ::core::ops::BitOr for SHUTDOWN_REASON {
     type Output = Self;
     fn bitor(self, other: Self) -> Self {
@@ -438,53 +454,5 @@ impl ::core::ops::Not for SHUTDOWN_REASON {
         Self(self.0.not())
     }
 }
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const SHUTDOWN_TYPE_LEN: u32 = 32u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const SNAPSHOT_POLICY_ALWAYS: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const SNAPSHOT_POLICY_NEVER: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`*"]
-pub const SNAPSHOT_POLICY_UNPLANNED: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn ShutdownBlockReasonCreate<'a, P0, P1>(hwnd: P0, pwszreason: P1) -> super::super::Foundation::BOOL
-where
-    P0: ::std::convert::Into<super::super::Foundation::HWND>,
-    P1: ::std::convert::Into<::windows::core::PCWSTR>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn ShutdownBlockReasonCreate(hwnd: super::super::Foundation::HWND, pwszreason: ::windows::core::PCWSTR) -> super::super::Foundation::BOOL;
-    }
-    ShutdownBlockReasonCreate(hwnd.into(), pwszreason.into())
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn ShutdownBlockReasonDestroy<'a, P0>(hwnd: P0) -> super::super::Foundation::BOOL
-where
-    P0: ::std::convert::Into<super::super::Foundation::HWND>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn ShutdownBlockReasonDestroy(hwnd: super::super::Foundation::HWND) -> super::super::Foundation::BOOL;
-    }
-    ShutdownBlockReasonDestroy(hwnd.into())
-}
-#[doc = "*Required features: `\"Win32_System_Shutdown\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn ShutdownBlockReasonQuery<'a, P0>(hwnd: P0, pwszbuff: ::windows::core::PWSTR, pcchbuff: *mut u32) -> super::super::Foundation::BOOL
-where
-    P0: ::std::convert::Into<super::super::Foundation::HWND>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn ShutdownBlockReasonQuery(hwnd: super::super::Foundation::HWND, pwszbuff: ::windows::core::PWSTR, pcchbuff: *mut u32) -> super::super::Foundation::BOOL;
-    }
-    ShutdownBlockReasonQuery(hwnd.into(), ::core::mem::transmute(pwszbuff), ::core::mem::transmute(pcchbuff))
-}
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
